@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
    are executed in sequence. Possible actions:
 
    beep              --  Produce audible signal
-   echo STRING       --  Output STRING to the user's tty
+   echo ARGS...      --  Output ARGS to the user's tty
    exec PROG ARGS... --  Execute given program (absolute pathname
                          required)
 
@@ -36,16 +36,17 @@
    $h        --  Expands to hostname
    $H{name}  --  Expands to value of message header `name'
    $B(C,L)   --  Expands to message body. C and L give maximum
-                 number of characters and line in the expansion.
+                 number of characters and lines in the expansion.
 		 When omitted, they default to 400, 5. */
 
-static int
+static unsigned
 act_getline (FILE *fp, char **sptr, size_t *size)
 {
   char buf[256];
   int cont = 1;
   size_t used = 0;
-
+  unsigned lines = 0;
+  
   while (cont && fgets (buf, sizeof buf, fp))
     {
       int len = strlen (buf);
@@ -56,6 +57,7 @@ act_getline (FILE *fp, char **sptr, size_t *size)
 	    {
 	      buf[--len] = 0;
 	      cont = 1;
+	      lines++;
 	    }
 	  else
 	    cont = 0;
@@ -67,7 +69,7 @@ act_getline (FILE *fp, char **sptr, size_t *size)
 	{
 	  *sptr = realloc (*sptr, len + used + 1);
 	  if (!*sptr)
-	    return -1;
+	    return 0;
 	  *size = len + used + 1;
 	}
       memcpy (*sptr + used, buf, len);
@@ -77,18 +79,20 @@ act_getline (FILE *fp, char **sptr, size_t *size)
   if (*sptr)
     (*sptr)[used] = 0;
 
-  return used;
+  if (used && !feof (fp))
+    lines++;
+  return lines;
 }
 
 static int
-expand_escape (char **pp, message_t msg, struct obstack *stk)
+expand_escape (char **pp, mu_message_t msg, struct obstack *stk)
 {
   char *p = *pp;
   char *start, *sval, *namep;
   int len;
-  header_t hdr;
-  body_t body;
-  stream_t stream;
+  mu_header_t hdr;
+  mu_body_t body;
+  mu_stream_t stream;
   int rc = 1;
   size_t size = 0, lncount = 0;
 
@@ -122,8 +126,8 @@ expand_escape (char **pp, message_t msg, struct obstack *stk)
 	break;
       memcpy (namep, start, len);
       namep[len] = 0;
-      if (message_get_header (msg, &hdr) == 0
-	  && header_aget_value (hdr, namep, &sval) == 0)
+      if (mu_message_get_header (msg, &hdr) == 0
+	  && mu_header_aget_value (hdr, namep, &sval) == 0)
 	{
 	  len = strlen (sval);
 	  obstack_grow (stk, sval, len);
@@ -147,15 +151,15 @@ expand_escape (char **pp, message_t msg, struct obstack *stk)
 	size = 400;
       if (lncount == 0)
 	lncount = maxlines;
-      if (message_get_body (msg, &body) == 0
-	  && body_get_stream (body, &stream) == 0)
+      if (mu_message_get_body (msg, &body) == 0
+	  && mu_body_get_stream (body, &stream) == 0)
 	{
 	  size_t nread;
 	  char *buf = malloc (size+1);
 
 	  if (!buf)
 	    break;
- 	  if (stream_read (stream, buf, size, 0, &nread) == 0)
+ 	  if (mu_stream_read (stream, buf, size, 0, &nread) == 0)
 	    {
 	      char *q;
 
@@ -181,7 +185,7 @@ expand_escape (char **pp, message_t msg, struct obstack *stk)
 }
 
 static char *
-expand_line (const char *str, message_t msg)
+expand_line (const char *str, mu_message_t msg)
 {
   const char *p;
   int c = 0;
@@ -198,7 +202,7 @@ expand_line (const char *str, message_t msg)
 	  p++;
 	  if (*p)
 	    {
-	      c = argcv_unescape_char (*p);
+	      c = mu_argcv_unquote_char (*p);
 	      obstack_1grow (&stk, c);
 	    }
 	  break;
@@ -237,7 +241,7 @@ action_beep (FILE *tty)
 }
 
 static void
-action_echo (FILE *tty, const char *cr, char *str)
+echo_string (FILE *tty, const char *cr, char *str)
 {
   if (!str)
     return;
@@ -254,6 +258,32 @@ action_echo (FILE *tty, const char *cr, char *str)
   fflush (tty);
 }
 
+static void
+action_echo (FILE *tty, const char *cr, int omit_newline,
+	     int argc, char **argv)
+{
+  int i;
+
+  if (omit_newline)
+    {
+      argc--;
+      argv++;
+    }
+  
+  for (i = 0;;)
+    {
+      echo_string (tty, cr, argv[i]);
+      if (++i < argc)
+	echo_string (tty, cr, " ");
+      else
+	{
+	  if (!omit_newline)
+	    echo_string (tty, cr, "\n");
+	  break;
+	}
+    }
+}
+
 static void
 action_exec (FILE *tty, int line, int argc, char **argv)
 {
@@ -331,64 +361,74 @@ open_rc (const char *filename, FILE *tty)
 }
 
 void
-run_user_action (FILE *tty, const char *cr, message_t msg)
+run_user_action (FILE *tty, const char *cr, mu_message_t msg)
 {
   FILE *fp;
   int nact = 0;
   char *stmt = NULL;
   size_t size = 0;
-
+  
   fp = open_rc (BIFF_RC, tty);
   if (fp)
     {
-      int line = 0;
+      unsigned line = 1, n;
 
-      while (act_getline (fp, &stmt, &size))
+      while ((n = act_getline (fp, &stmt, &size)))
 	{
-	  char *str;
 	  int argc;
 	  char **argv;
 
-	  line++;
-	  str = expand_line (stmt, msg);
-	  if (!str)
-	    continue;
-	  if (argcv_get (str, "", NULL, &argc, &argv)
-	      || argc == 0
-	      || argv[0][0] == '#')
+	  if (mu_argcv_get (stmt, "", NULL, &argc, &argv) == 0
+	      && argc
+	      && argv[0][0] != '#')
 	    {
-	      free (str);
-	      argcv_free (argc, argv);
-	      continue;
-	    }
-
-	  if (strcmp (argv[0], "beep") == 0)
-	    {
-	      action_beep (tty);
-	      nact++;
-	    }
-	  else if (strcmp (argv[0], "echo") == 0)
-	    {
-	      action_echo (tty, cr, argv[1]);
-	      nact++;
-	    }
-	  else if (strcmp (argv[0], "exec") == 0)
-	    {
-	      action_exec (tty, line, argc-1, argv+1);
-	      nact++;
-	    }
-	  else
-	    {
-	      fprintf (tty, _(".biffrc:%d: unknown keyword"), line);
-	      fprintf (tty, "\r\n");
-	      syslog (LOG_ERR, _("%s:.biffrc:%d: unknown keyword %s"),
-		      username, line, argv[0]);
-	      break;
+	      if (strcmp (argv[0], "beep") == 0)
+		{
+		  /* FIXME: excess arguments are ignored */
+		  action_beep (tty);
+		  nact++;
+		}
+	      else
+		{
+		  /* Rest of actions require keyword expansion */
+		  int i;
+		  int n_option = argc > 1 && strcmp (argv[1], "-n") == 0;
+		  
+		  for (i = 1; i < argc; i++)
+		    {
+		      char *oldarg = argv[i];
+		      argv[i] = expand_line (argv[i], msg);
+		      free (oldarg);
+		      if (!argv[i])
+			break;
+		    }
+		  
+		  if (strcmp (argv[0], "echo") == 0)
+		    {
+		      action_echo (tty, cr, n_option, argc - 1, argv + 1);
+		      nact++;
+		    }
+		  else if (strcmp (argv[0], "exec") == 0)
+		    {
+		      action_exec (tty, line, argc - 1, argv + 1);
+		      nact++;
+		    }
+		  else
+		    {
+		      fprintf (tty, _(".biffrc:%d: unknown keyword"), line);
+		      fprintf (tty, "\r\n");
+		      syslog (LOG_ERR, _("%s:.biffrc:%d: unknown keyword %s"),
+			      username, line, argv[0]);
+		      break;
+		    }
+		} 
 	    }
+	  mu_argcv_free (argc, argv);
+	  line += n;
 	}
       fclose (fp);
     }
 
   if (nact == 0)
-    action_echo (tty, cr, expand_line (default_action, msg));
+    echo_string (tty, cr, expand_line (default_action, msg));
 }
