@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "comsat.h"
 
@@ -29,8 +30,8 @@
 #endif
 
 #ifndef HAVE_GETUTENT_CALLS
-extern void setutent __P((void));
-extern struct utmp *getutent __P((void));
+extern void setutent (void);
+extern struct utmp *getutent (void);
 #endif
 
 #ifdef UTMPX
@@ -179,10 +180,10 @@ main(int argc, char **argv)
 static RETSIGTYPE
 sig_hup (int sig)
 {
-  syslog (LOG_NOTICE, _("restarting"));
+  syslog (LOG_NOTICE, _("Restarting"));
 
   if (xargv[0][0] != '/')
-    syslog (LOG_ERR, _("can't restart: not started with absolute pathname"));
+    syslog (LOG_ERR, _("Cannot restart: program must be invoked using absolute pathname"));
   else
     execvp (xargv[0], xargv);
 
@@ -192,11 +193,7 @@ sig_hup (int sig)
 void
 comsat_init ()
 {
-  list_t bookie;
-
-  registrar_get_list (&bookie);
-  /* list_append (bookie, mbox_record); */
-  list_append (bookie, path_record);
+  mu_registrar_record (mu_path_record);
 
   gethostname (hostname, sizeof hostname);
 
@@ -213,10 +210,10 @@ comsat_daemon_init (void)
   extern int daemon (int, int);
 
   /* Become a daemon. Take care to close inherited fds and to hold
-     first three one, in, out, err.  Do not do the chdir("/").   */
+     first three ones, in, out, err.  Do not do the chdir("/").   */
   if (daemon (1, 0) < 0)
     {
-      perror (_("failed to become a daemon"));
+      perror (_("Failed to become a daemon"));
       exit (EXIT_FAILURE);
     }
 }
@@ -288,8 +285,8 @@ comsat_daemon (int port)
 
 	      delay = overflow_delay_time << (overflow_count + 1);
 	      syslog (LOG_NOTICE,
-		      ngettext ("too many requests: pausing for %u second",
-				"too many requests: pausing for %u seconds",
+		      ngettext ("Too many requests: pausing for %u second",
+				"Too many requests: pausing for %u seconds",
 				delay),
 		      delay);
 	      sleep (delay);
@@ -349,8 +346,8 @@ comsat_main (int fd)
     }
 
   syslog (LOG_INFO,
-	  ngettext ("received %d byte from %s",
-		    "received %d bytes from %s", rdlen),
+	  ngettext ("Received %d byte from %s",
+		    "Received %d bytes from %s", rdlen),
 	  rdlen, inet_ntoa (sin_from.sin_addr));
 
   buffer[rdlen] = 0;
@@ -359,7 +356,7 @@ comsat_main (int fd)
   p = strchr (buffer, '@');
   if (!p)
     {
-      syslog (LOG_ERR, _("malformed input: %s"), buffer);
+      syslog (LOG_ERR, _("Malformed input: %s"), buffer);
       return 1;
     }
   *p++ = 0;
@@ -374,7 +371,7 @@ comsat_main (int fd)
       break;
     default:
       if (!isspace (*endp))
-	syslog (LOG_ERR, _("malformed input: %s@%s (near %s)"), buffer, p, endp);
+	syslog (LOG_ERR, _("Malformed input: %s@%s (near %s)"), buffer, p, endp);
     }
 
   if (find_user (buffer, tty) != SUCCESS)
@@ -430,9 +427,9 @@ notify_user (const char *user, const char *device, const char *path, off_t offse
   FILE *fp;
   const char *cr;
   char *blurb;
-  mailbox_t mbox = NULL, tmp = NULL;
-  message_t msg;
-  stream_t stream = NULL;
+  mu_mailbox_t mbox = NULL, tmp = NULL;
+  mu_message_t msg;
+  mu_stream_t stream = NULL;
   int status;
   off_t size;
   size_t count, n;
@@ -440,7 +437,7 @@ notify_user (const char *user, const char *device, const char *path, off_t offse
   change_user (user);
   if ((fp = fopen (device, "w")) == NULL)
     {
-      syslog (LOG_ERR, _("can't open device %s: %m"), device);
+      syslog (LOG_ERR, _("Cannot open device %s: %m"), device);
       exit (0);
     }
 
@@ -453,24 +450,24 @@ notify_user (const char *user, const char *device, const char *path, off_t offse
 	return;
     }
 
-  if ((status = mailbox_create (&mbox, path)) != 0
-      || (status = mailbox_open (mbox, MU_STREAM_READ)) != 0)
+  if ((status = mu_mailbox_create (&mbox, path)) != 0
+      || (status = mu_mailbox_open (mbox, MU_STREAM_READ)) != 0)
     {
-      syslog (LOG_ERR, _("can't open mailbox %s: %s"),
+      syslog (LOG_ERR, _("Cannot open mailbox %s: %s"),
 	      path, mu_strerror (status));
       return;
     }
 
-  if ((status = mailbox_get_stream (mbox, &stream)))
+  if ((status = mu_mailbox_get_stream (mbox, &stream)))
     {
-      syslog (LOG_ERR, _("can't get stream for mailbox %s: %s"),
+      syslog (LOG_ERR, _("Cannot get stream for mailbox %s: %s"),
 	      path, mu_strerror (status));
       return;
     }
 
-  if ((status = stream_size (stream, &size)))
+  if ((status = mu_stream_size (stream, &size)))
     {
-      syslog (LOG_ERR, _("can't get stream size (mailbox %s): %s"),
+      syslog (LOG_ERR, _("Cannot get stream size (mailbox %s): %s"),
 	      path, mu_strerror (status));
       return;
     }
@@ -481,28 +478,28 @@ notify_user (const char *user, const char *device, const char *path, off_t offse
   if (!blurb)
     return;
 
-  stream_read (stream, blurb, size, offset, &n);
+  mu_stream_read (stream, blurb, size, offset, &n);
   blurb[size] = 0;
 
-  if ((status = mailbox_create (&tmp, "/dev/null")) != 0
-      || (status = mailbox_open (tmp, MU_STREAM_READ)) != 0)
+  if ((status = mu_mailbox_create (&tmp, "/dev/null")) != 0
+      || (status = mu_mailbox_open (tmp, MU_STREAM_READ)) != 0)
     {
-      syslog (LOG_ERR, _("can't create temporary mailbox: %s"),
+      syslog (LOG_ERR, _("Cannot create temporary mailbox: %s"),
 	      mu_strerror (status));
       return;
     }
 
-  if ((status = memory_stream_create (&stream, 0, 0)))
+  if ((status = mu_memory_stream_create (&stream, 0, 0)))
     {
-      syslog (LOG_ERR, _("can't create temporary stream: %s"),
+      syslog (LOG_ERR, _("Cannot create temporary stream: %s"),
 	      mu_strerror (status));
       return;
     }
 
-  stream_write (stream, blurb, size, 0, &count);
-  mailbox_set_stream (tmp, stream);
-  mailbox_messages_count (tmp, &count);
-  mailbox_get_message (tmp, 1, &msg);
+  mu_stream_write (stream, blurb, size, 0, &count);
+  mu_mailbox_set_stream (tmp, stream);
+  mu_mailbox_messages_count (tmp, &count);
+  mu_mailbox_get_message (tmp, 1, &msg);
 
   run_user_action (fp, cr, msg);
   fclose (fp);
@@ -541,7 +538,7 @@ find_user (const char *name, char *tty)
 	  if (strncmp (ftty, PATH_TTY_PFX, strlen (PATH_TTY_PFX)))
 	    {
 	      /* An attempt to break security... */
-	      syslog (LOG_ALERT, _("bad line name in utmp record: %s"), ftty);
+	      syslog (LOG_ALERT, _("Bad line name in utmp record: %s"), ftty);
 	      return NOT_HERE;
 	    }
 
@@ -549,7 +546,7 @@ find_user (const char *name, char *tty)
 	    {
 	      if (!S_ISCHR (statb.st_mode))
 		{
-		  syslog (LOG_ALERT, _("not a character device: %s"), ftty);
+		  syslog (LOG_ALERT, _("Not a character device: %s"), ftty);
 		  return NOT_HERE;
 		}
 
@@ -582,7 +579,7 @@ change_user (const char *user)
   pw = getpwnam (user);
   if (!pw)
     {
-      syslog (LOG_CRIT, _("no such user: %s"), user);
+      syslog (LOG_CRIT, _("No such user: %s"), user);
       exit (1);
     }
 
@@ -602,7 +599,7 @@ mailbox_path (const char *user)
 
   if (!auth)
     {
-      syslog (LOG_ALERT, _("user nonexistent: %s"), user);
+      syslog (LOG_ALERT, _("User nonexistent: %s"), user);
       return NULL;
     }
 
