@@ -72,12 +72,12 @@ char *from_person = NULL; /* Set the name of the `from' person */
 int read_recipients = 0; /* Read the message for recipients */
 int dot = 1;             /* Message is terminated by a lone dot on a line */
 
-address_t recipients = NULL;
+mu_address_t recipients = NULL;
 char *progname;
 
-int mta_stdin __P((int argc, char **argv));
-int mta_smtp __P((int argc, char **argv));
-void register_handlers __P((void));
+int mta_stdin (int argc, char **argv);
+int mta_smtp (int argc, char **argv);
+void register_handlers (void);
 
 int
 main (int argc, char **argv)
@@ -251,41 +251,38 @@ make_tmp (FILE *input, const char *from, char **tempfile)
 void
 register_handlers ()
 {
-  list_t bookie;
-
-  registrar_get_list (&bookie);
-  list_append (bookie, path_record);
-  list_append (bookie, sendmail_record);
-  list_append (bookie, smtp_record);
+  mu_registrar_record (mu_path_record);
+  mu_registrar_record (mu_sendmail_record);
+  mu_registrar_record (mu_smtp_record);
 }
 
 int
 add_recipient (const char *name)
 {
-  address_t addr;
+  mu_address_t addr;
   int status;
     
-  status = address_create (&addr, name);
+  status = mu_address_create (&addr, name);
   if (status == 0)
-    status = address_union (&recipients, addr);
-  address_destroy (&addr);
+    status = mu_address_union (&recipients, addr);
+  mu_address_destroy (&addr);
   return status;
 }
 
 /* Convert addr to a comma-separated list of email addresses,
    suitable as an argument to RCPT TO command */
 char *
-address_email_string (address_t addr)
+address_email_string (mu_address_t addr)
 {
   size_t count, i, n, length;
   char *value, *p;
   
-  address_get_email_count (addr, &count);
+  mu_address_get_email_count (addr, &count);
   length = 0;
   for (i = 1; i <= count; i++)
     {
       char *str;
-      address_aget_email (recipients, i, &str);
+      mu_address_aget_email (recipients, i, &str);
       length += strlen (str) + 3;
       free (str);
     }
@@ -300,7 +297,7 @@ address_email_string (address_t addr)
   for (i = 1; i <= count; i++)
     {
       *p++ = '<';
-      address_get_email (recipients, i, p, length - (p - value), &n);
+      mu_address_get_email (recipients, i, p, length - (p - value), &n);
       p += n;
       *p++ = '>';
       if (i + 1 <= count)
@@ -311,11 +308,11 @@ address_email_string (address_t addr)
 }
 
 int
-mta_send (message_t msg)
+mta_send (mu_message_t msg)
 {
   size_t n;
   char buffer[512];    
-  stream_t stream = NULL;
+  mu_stream_t stream = NULL;
   size_t off = 0, line;
   char *value;
 
@@ -330,10 +327,10 @@ mta_send (message_t msg)
   fprintf (diag, "ENVELOPE TO: %s\n", value);
   free (value);
 
-  message_get_stream (msg, &stream);
+  mu_message_get_stream (msg, &stream);
   line = 0;
   fprintf (diag, "%4lu: ", (unsigned long) line);
-  while (stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
+  while (mu_stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
 	 && n != 0)
     {
       size_t i;
@@ -357,13 +354,13 @@ mta_send (message_t msg)
 #define SENDER_WARNING "set sender using -f flag"
 
 int
-message_finalize (message_t msg, int warn)
+message_finalize (mu_message_t msg, int warn)
 {
-  header_t header = NULL;
+  mu_header_t header = NULL;
   int have_to;
   char *value = NULL;
   
-  message_get_header (msg, &header);
+  mu_message_get_header (msg, &header);
 
   if (warn && from_person)
     {
@@ -376,11 +373,11 @@ message_finalize (message_t msg, int warn)
 	  return 1;
 	}
       sprintf (warn, "%s %s", pwd->pw_name, SENDER_WARNING);
-      header_set_value (header, "X-Authentication-Warning", warn, 0);
+      mu_header_set_value (header, "X-Authentication-Warning", warn, 0);
       free (warn);
     }
   
-  have_to = header_aget_value (header, MU_HEADER_TO, &value) == 0;
+  have_to = mu_header_aget_value (header, MU_HEADER_TO, &value) == 0;
   
   if (read_recipients)
     {
@@ -394,7 +391,7 @@ message_finalize (message_t msg, int warn)
 	  free (value);
 	}
 	  
-      if (header_aget_value (header, MU_HEADER_CC, &value) == 0)
+      if (mu_header_aget_value (header, MU_HEADER_CC, &value) == 0)
 	{
 	  if (add_recipient (value))
 	    {
@@ -404,7 +401,7 @@ message_finalize (message_t msg, int warn)
 	  free (value);
 	}  
 	  
-      if (header_aget_value (header, MU_HEADER_BCC, &value) == 0)
+      if (mu_header_aget_value (header, MU_HEADER_BCC, &value) == 0)
 	{
 	  if (add_recipient (value))
 	    {
@@ -412,7 +409,7 @@ message_finalize (message_t msg, int warn)
 	      return 1;
 	    }
 	  free (value);
-	  header_set_value (header, MU_HEADER_BCC, NULL, 1);
+	  mu_header_set_value (header, MU_HEADER_BCC, NULL, 1);
 	}  
     }
 
@@ -421,10 +418,10 @@ message_finalize (message_t msg, int warn)
       size_t n;
       int c;
       
-      c = address_to_string (recipients, NULL, 0, &n);
+      c = mu_address_to_string (recipients, NULL, 0, &n);
       if (c)
 	{
-	  mu_error ("%s: address_to_string failure: %s",
+	  mu_error ("%s: mu_address_to_string failure: %s",
 		    progname, mu_strerror (c));
 	  return 1;
 	}
@@ -435,8 +432,8 @@ message_finalize (message_t msg, int warn)
 	  return 1;
 	}
 
-      address_to_string (recipients, value, n + 1, &n);
-      header_set_value (header, MU_HEADER_TO, value, 1);
+      mu_address_to_string (recipients, value, n + 1, &n);
+      mu_header_set_value (header, MU_HEADER_TO, value, 1);
       free (value);
     }
   return 0;
@@ -447,8 +444,8 @@ mta_stdin (int argc, char **argv)
 {
   int c;
   char *tempfile;
-  mailbox_t mbox;
-  message_t msg = NULL;
+  mu_mailbox_t mbox;
+  mu_message_t msg = NULL;
   
   for (c = 0; c < argc; c++)
     {
@@ -460,7 +457,7 @@ mta_stdin (int argc, char **argv)
     }
 
   make_tmp (stdin, from_person, &tempfile);
-  if ((c = mailbox_create_default (&mbox, tempfile)) != 0)
+  if ((c = mu_mailbox_create_default (&mbox, tempfile)) != 0)
     {
       mu_error ("%s: can't create mailbox %s: %s",
 		progname, tempfile, mu_strerror (c));
@@ -468,7 +465,7 @@ mta_stdin (int argc, char **argv)
       return 1;
     }
 
-  if ((c = mailbox_open (mbox, MU_STREAM_RDWR)) != 0)
+  if ((c = mu_mailbox_open (mbox, MU_STREAM_RDWR)) != 0)
     {
       mu_error ("%s: can't open mailbox %s: %s",
 		progname, tempfile, mu_strerror (c));
@@ -476,7 +473,7 @@ mta_stdin (int argc, char **argv)
       return 1;
     }
 
-  mailbox_get_message (mbox, 1, &msg);
+  mu_mailbox_get_message (mbox, 1, &msg);
   if (message_finalize (msg, 1))
     return 1;
 
@@ -553,8 +550,8 @@ smtp (int fd)
   int state, c;
   char *buf = NULL;
   size_t size = 0;
-  mailbox_t mbox;
-  message_t msg;
+  mu_mailbox_t mbox;
+  mu_message_t msg;
   char *tempfile;
   
   in = fdopen (fd, "r");
@@ -576,7 +573,7 @@ smtp (int fd)
 	len --;
       buf[len] = 0;
       
-      if (argcv_get (buf, "", NULL, &argc, &argv))
+      if (mu_argcv_get (buf, "", NULL, &argc, &argv))
 	exit (1);
 
       kw = smtp_kw (argv[0]);
@@ -584,7 +581,7 @@ smtp (int fd)
 	{
 	  smtp_reply (221, "Done");
 	  state = STATE_QUIT;
-	  argcv_free (argc, argv);
+	  mu_argcv_free (argc, argv);
 	  continue;
 	}
       
@@ -671,7 +668,7 @@ smtp (int fd)
 	      smtp_reply (354,
 			  "Enter mail, end with \".\" on a line by itself");
 	      make_tmp (in, from_person, &tempfile);
-	      if ((c = mailbox_create_default (&mbox, tempfile)) != 0)
+	      if ((c = mu_mailbox_create_default (&mbox, tempfile)) != 0)
 		{
 		  mu_error ("%s: can't create mailbox %s: %s",
 			    progname,
@@ -680,7 +677,7 @@ smtp (int fd)
 		  exit (1);
 		}
 
-	      if ((c = mailbox_open (mbox, MU_STREAM_RDWR)) != 0)
+	      if ((c = mu_mailbox_open (mbox, MU_STREAM_RDWR)) != 0)
 		{
 		  mu_error ("%s: can't open mailbox %s: %s",
 			    progname, 
@@ -689,14 +686,14 @@ smtp (int fd)
 		  exit (1);
 		}
 
-	      mailbox_get_message (mbox, 1, &msg);
+	      mu_mailbox_get_message (mbox, 1, &msg);
 	      if (message_finalize (msg, 0) == 0)
 		mta_send (msg);
 	      else
 		smtp_reply (501, "can't send message"); /*FIXME: code?*/
 	      unlink (tempfile);
 
-	      address_destroy (&recipients);
+	      mu_address_destroy (&recipients);
 	      from_person = NULL;
 	      
 	      smtp_reply (250, "Message accepted for delivery");
@@ -710,7 +707,7 @@ smtp (int fd)
 	  break;
 
 	}
-      argcv_free (argc, argv);
+      mu_argcv_free (argc, argv);
     }
     
   close (fd);
@@ -763,11 +760,11 @@ mta_smtp (int argc, char **argv)
 	  status = bind (fd, (struct sockaddr *) &address, sizeof (address));
 	}
       while (status < 0);
-      printf ("%d\n", port);
-      fclose (stdout);
     }
 
   listen (fd, 5);
+  printf ("%d\n", port);
+  fclose (stdout);
   while (1)
     {
       fd_set rfds;
