@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2003, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2003, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -47,20 +48,22 @@ imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
      currently selected mailbox without doing an expunge.  */
   if (mbox)
     {
-      mailbox_save_attributes (mbox);
-      mailbox_close (mbox);
-      mailbox_destroy (&mbox);
+      mu_mailbox_save_attributes (mbox);
+      mu_mailbox_close (mbox);
+      mu_mailbox_destroy (&mbox);
       /* Destroy the old uid table.  */
       imap4d_sync ();
     }
 
+  if (strcmp (mailbox_name, "INBOX") == 0)
+    flags |= MU_STREAM_CREAT;
   mailbox_name = namespace_getfullpath (mailbox_name, "/");
 
   if (!mailbox_name)
     return util_finish (command, RESP_NO, "Couldn't open mailbox");
 
-  if ((status = mailbox_create (&mbox, mailbox_name)) == 0
-      && (status = mailbox_open (mbox, flags)) == 0)
+  if ((status = mu_mailbox_create (&mbox, mailbox_name)) == 0
+      && (status = mu_mailbox_open (mbox, flags)) == 0)
     {
       select_flags = flags;
       state = STATE_SEL;
@@ -72,7 +75,7 @@ imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
 	  free (mailbox_name);
 	  /* Need to set the state explicitely for select.  */
 	  return util_send ("%s OK [%s] %s Completed\r\n", command->tag,
-			    (MU_STREAM_READ == flags) ?
+			    (flags & MU_STREAM_READ)  ?
 			    "READ-ONLY" : "READ-WRITE", command->name);
 	}
     }
@@ -96,10 +99,10 @@ imap4d_select_status ()
     return 0; /* FIXME: this should be something! */
 
   if ((status = util_uidvalidity (mbox, &uidvalidity))
-      || (status = mailbox_uidnext (mbox, &uidnext))
-      || (status = mailbox_messages_count (mbox, &count))
-      || (status = mailbox_messages_recent (mbox, &recent))
-      || (status = mailbox_message_unseen (mbox, &unseen)))
+      || (status = mu_mailbox_uidnext (mbox, &uidnext))
+      || (status = mu_mailbox_messages_count (mbox, &count))
+      || (status = mu_mailbox_messages_recent (mbox, &recent))
+      || (status = mu_mailbox_message_unseen (mbox, &unseen)))
     return status;
 
   /* This outputs EXISTS and RECENT responses */
