@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -34,17 +35,29 @@ imap4d_starttls (struct imap4d_command *command, char *arg)
   if (util_getword (arg, &sp))
     return util_finish (command, RESP_BAD, "Too many args");
 
+  util_atexit (mu_deinit_tls_libs);
+
   status = util_finish (command, RESP_OK, "Begin TLS negotiation");
   util_flush_output ();
   tls_done = imap4d_init_tls_server ();
 
   if (tls_done)
     {
-      imap4d_capability_remove ("STARTTLS");
+      imap4d_capability_remove (IMAP_CAPA_STARTTLS);
+      
       login_disabled = 0;
-      imap4d_capability_remove ("LOGINDISABLED");
-      util_atexit (mu_deinit_tls_libs);
+      imap4d_capability_remove (IMAP_CAPA_LOGINDISABLED);
+
+      tls_required = 0;
+      imap4d_capability_remove (IMAP_CAPA_XTLSREQUIRED);
     }
+  else
+    {
+      syslog (LOG_ERR, _("Session terminated"));
+      util_bye ();
+      exit (0);
+    }
+
   return status;
 }
 
@@ -55,7 +68,7 @@ starttls_init ()
   if (tls_available)
     tls_available = mu_init_tls_libs ();
   if (tls_available)
-    imap4d_capability_add ("STARTTLS");
+    imap4d_capability_add (IMAP_CAPA_STARTTLS);
 }
 
 #endif /* WITH_TLS */
