@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,19 +11,22 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_GSASL_H
 #define _MAILUTILS_GSASL_H
 
-int gsasl_stream_create __P((stream_t *stream, int fd,
-			     Gsasl_session_ctx *ctx,
-			     int flags));
+#include <gsasl.h>
 
-void mu_gsasl_init_argp __P((void));
+int mu_gsasl_stream_create (mu_stream_t *stream, mu_stream_t transport,
+			 Gsasl_session_ctx *ctx,
+			 int flags);
 
-extern char *gsasl_cram_md5_pwd;
+void mu_gsasl_init_argp (void);
 
-#endif
+extern char *mu_gsasl_cram_md5_pwd;
+
+#endif /* not _MAILUTILS_GSASL_H */
