@@ -17,7 +17,11 @@
 ;;;; Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ;;;;
 
-(define-module (mailutils mailutils))
+(define-module (mailutils mailutils)
+               #:use-module (ice-9 documentation))
+
+(set! documentation-files (append documentation-files 
+                                  (list "/usr/local/share/mailutils/1.0.1/guile/mailutils/guile-procedures.txt")))
 
 (define mu-libs (list "libmailutils"
 		      "libmuauth"
@@ -27,7 +31,7 @@
 		      "libmu_pop"
 		      "libmu_imap"))
 
-(let ((lib-path "/home/gray/alpha/lib/"))
+(let ((lib-path "/usr/local/lib/"))
   (for-each
    (lambda (lib)
 	   (dynamic-link (string-append lib-path lib)))
@@ -38,10 +42,10 @@
     (dynamic-call "mu_scm_init"
 		  (dynamic-link (string-append
 				 lib-path
-				 "libguile-mailutils-v-0.6.94"))))
+				 "libguile-mailutils-v-1.0.1"))))
    (else
     (load-extension (string-append
-		     lib-path "libguile-mailutils-v-0.6.94") "mu_scm_init"))))
+		     lib-path "libguile-mailutils-v-1.0.1") "mu_scm_init"))))
 
 (export mu-package)
 (export mu-package-string)
@@ -104,7 +108,6 @@
 (export mu-mailbox-get-message)
 (export mu-mailbox-messages-count)
 (export mu-mailbox-expunge)
-(export mu-mailbox-url)
 (export mu-mailbox-append-message)
 
 (export mu-message-create)
