@@ -154,6 +154,7 @@ struct mail_env_entry
   {
     char *string;
     int number;
+    int bool;
   }
   value;
 };
@@ -174,7 +175,6 @@ typedef int (*msg_handler_t) (msgset_t *mp, mu_message_t mesg, void *data);
 
 /* Global variables and constants*/
 extern mu_mailbox_t mbox;
-extern size_t cursor;
 extern size_t total;
 extern FILE *ofile;
 extern int interactive;
