@@ -26,19 +26,18 @@
  */
 
 static int
-mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
+mail_print_msg (msgset_t *mspec, mu_message_t mesg, void *data)
 {
-  header_t hdr;
-  body_t body;
-  stream_t stream;
+  mu_header_t hdr;
+  mu_body_t body;
+  mu_stream_t stream;
   char buffer[512];
   off_t off = 0;
   size_t n = 0, lines = 0;
   FILE *out = ofile;
-  attribute_t attr;
   int pagelines = util_get_crt ();
   
-  message_lines (mesg, &lines);
+  mu_message_lines (mesg, &lines);
 
   /* If it is POP or IMAP the lines number is not known, so try
      to be smart about it.  */
@@ -50,7 +49,7 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
 	  if (col)
 	    {
 	      size_t size = 0;
-	      message_size (mesg, &size);
+	      mu_message_size (mesg, &size);
 	      lines =  size / col;
 	    }
 	}
@@ -65,16 +64,16 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
       char buf[512];
       char *tmp;
       
-      message_get_header (mesg, &hdr);
-      header_get_field_count (hdr, &num);
+      mu_message_get_header (mesg, &hdr);
+      mu_header_get_field_count (hdr, &num);
 
       for (i = 1; i <= num; i++)
 	{
-	  header_get_field_name (hdr, i, buf, sizeof buf, NULL);
+	  mu_header_get_field_name (hdr, i, buf, sizeof buf, NULL);
 	  if (mail_header_is_visible (buf))
 	    {
 	      fprintf (out, "%s: ", buf);
-	      header_aget_field_value (hdr, i, &tmp);
+	      mu_header_aget_field_value (hdr, i, &tmp);
 	      if (mail_header_is_unfoldable (buf))
 		mu_string_unfold (tmp, NULL);
 	      util_rfc2047_decode (&tmp);
@@ -83,13 +82,13 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
 	    }
 	}
       fprintf (out, "\n");
-      message_get_body (mesg, &body);
-      body_get_stream (body, &stream);
+      mu_message_get_body (mesg, &body);
+      mu_body_get_stream (body, &stream);
     }
   else
-    message_get_stream (mesg, &stream);
+    mu_message_get_stream (mesg, &stream);
   
-  while (stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
+  while (mu_stream_read (stream, buffer, sizeof buffer - 1, off, &n) == 0
 	 && n != 0)
     {
       if (ml_got_interrupt())
@@ -106,7 +105,7 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
   
   util_mark_read (mesg);
 
-  cursor = mspec->msg_part[0];
+  set_cursor (mspec->msg_part[0]);
   
   return 0;
 }
