@@ -31,7 +31,8 @@ mail_set (int argc, char **argv)
 {
   if (argc < 2)
     {
-      return util_printenv (1);
+      util_printenv (1);
+      return 0;
     }
   else
     {
@@ -61,7 +62,7 @@ mail_set (int argc, char **argv)
 	    }
 	  else
 	    {
-	      int dummy;
+	      int dummy = 1;
 	      util_setenv (argv[i], &dummy, Mail_env_boolean, 1);
 	    }
 	}
