@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -22,15 +23,15 @@
  */
 
 static int
-size0 (msgset_t *mspec, message_t msg, void *data)
+size0 (msgset_t *mspec, mu_message_t msg, void *data)
 {
   size_t size = 0, lines = 0;
 
-  message_size (msg, &size);
-  message_lines (msg, &lines);
+  mu_message_size (msg, &size);
+  mu_message_lines (msg, &lines);
   
   fprintf (ofile, "%c%2d %3d/%-5d\n",
-	   mspec->msg_part[0] == cursor ? '>' : ' ',
+	   is_current_message (mspec->msg_part[0]) ? '>' : ' ',
 	   mspec->msg_part[0], lines, size);
   return 0;
 }
