@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -21,16 +22,16 @@
 /* unt[ag] [msglist] */
 
 static int
-tag_message (message_t mesg, msgset_t *msgset ARG_UNUSED, void *arg)
+tag_message (mu_message_t mesg, msgset_t *msgset ARG_UNUSED, void *arg)
 {
-  attribute_t attr;
+  mu_attribute_t attr;
   int *action = arg;
 
-  message_get_attribute (mesg, &attr);
+  mu_message_get_attribute (mesg, &attr);
   if (*action)
-    attribute_set_userflag (attr, MAIL_ATTRIBUTE_TAGGED);
+    mu_attribute_set_userflag (attr, MAIL_ATTRIBUTE_TAGGED);
   else
-    attribute_unset_userflag (attr, MAIL_ATTRIBUTE_TAGGED);
+    mu_attribute_unset_userflag (attr, MAIL_ATTRIBUTE_TAGGED);
   return 0;
 }
 
