@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005, 2006 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -41,12 +42,12 @@
 #include <mailutils/locker.h>
 #include <mailutils/mutil.h>
 
-#define LOCKFILE_ATTR           0444
+#define LOCKFILE_ATTR           0644
 
 /* First draft by Brian Edmond. */
 /* For subsequent modifications, see the GNU mailutils ChangeLog. */
 
-struct _locker
+struct _mu_locker
 {
   int refcnt;
 
@@ -78,31 +79,73 @@ struct _locker
  */
 #define INVARIANT(l) assert((l)->refcnt >= 0);
 
-static void expire_stale_lock __P((locker_t lock));
-static int stat_check __P((const char *file, int fd, int links));
-static int check_file_permissions __P((const char *file));
-static int lock_external __P((locker_t l, int lock)); 
-static int _locker_lock_dotlock __P((locker_t lock));
-static int _locker_unlock_dotlock __P((locker_t lock));
-static int _locker_lock_kernel __P((locker_t lock)); 
-static int _locker_unlock_kernel __P((locker_t lock));
+static void expire_stale_lock (mu_locker_t lock);
+static int stat_check (const char *file, int fd, int links);
+static int check_file_permissions (const char *file);
+static int lock_external (mu_locker_t l, int lock); 
+static int _locker_lock_dotlock (mu_locker_t lock);
+static int _locker_unlock_dotlock (mu_locker_t lock);
+static int _locker_lock_kernel (mu_locker_t lock); 
+static int _locker_unlock_kernel (mu_locker_t lock);
 
-static int locker_default_flags = MU_LOCKER_DEFAULT;
+static int mu_locker_default_flags = MU_LOCKER_DEFAULT;
+static time_t mu_locker_retry_timeout = MU_LOCKER_RETRY_SLEEP;
+static size_t mu_locker_retry_count = MU_LOCKER_RETRIES;
+static time_t mu_locker_expire_timeout = MU_LOCKER_EXPIRE_TIME;
+static char *mu_locker_external_program = NULL;
 
-int locker_set_default_flags(int flags)
+int
+mu_locker_set_default_flags (int flags, enum mu_locker_set_mode mode)
 {
-  if(flags == 0)
-    flags = MU_LOCKER_DEFAULT;
+  switch (mode)
+    {
+    case mu_locker_assign:
+      mu_locker_default_flags = flags;
+      break;
 
-  locker_default_flags = flags;
+    case mu_locker_set_bit:
+      mu_locker_default_flags |= flags;
+      break;
 
+    case mu_locker_clear_bit:
+      mu_locker_default_flags &= ~flags;
+      break;
+
+    default:
+      return EINVAL;
+    }
   return 0;
 }
 
-int
-locker_create (locker_t *plocker, const char *filename_, int flags)
+void
+mu_locker_set_default_retry_timeout (time_t to)
 {
-  locker_t l;
+  mu_locker_retry_timeout = to;
+}
+
+void
+mu_locker_set_default_retry_count (size_t n)
+{
+  mu_locker_retry_count = n;
+}
+
+void
+mu_locker_set_default_expire_timeout (time_t t)
+{
+  mu_locker_expire_timeout = t;
+}
+
+void
+mu_locker_set_default_external_program (char *path)
+{
+  free (mu_locker_external_program);
+  mu_locker_external_program = strdup (path);
+}
+
+int
+mu_locker_create (mu_locker_t *plocker, const char *filename_, int flags)
+{
+  mu_locker_t l;
   char filename[_POSIX_PATH_MAX];
   int err = 0;
 
@@ -133,18 +176,20 @@ locker_create (locker_t *plocker, const char *filename_, int flags)
   else if (flags)
     l->flags = flags;
   else
-    l->flags = locker_default_flags;
+    l->flags = mu_locker_default_flags;
 
-  l->expire_time = MU_LOCKER_EXPIRE_TIME;
-  l->retries = MU_LOCKER_RETRIES;
-  l->retry_sleep = MU_LOCKER_RETRY_SLEEP;
+  l->expire_time = mu_locker_expire_timeout;
+  l->retries = mu_locker_retry_count;
+  l->retry_sleep = mu_locker_retry_timeout;
 
   /* Initialize locker-type-specific data */
   if (l->flags & MU_LOCKER_EXTERNAL)
     {
-      if (!(l->data.external.name = strdup (MU_LOCKER_EXTERNAL_PROGRAM)))
+      if (!(l->data.external.name = strdup (mu_locker_external_program ?
+					    mu_locker_external_program :
+					    MU_LOCKER_EXTERNAL_PROGRAM)))
 	{
-	  locker_destroy (&l);
+	  mu_locker_destroy (&l);
 	  return ENOMEM;
 	}
     }
@@ -171,7 +216,7 @@ locker_create (locker_t *plocker, const char *filename_, int flags)
 }
 
 void
-_locker_destroy_private (locker_t locker)
+_locker_destroy_private (mu_locker_t locker)
 {
   if (locker)
     {
@@ -190,7 +235,7 @@ _locker_destroy_private (locker_t locker)
 }
 
 void
-locker_destroy (locker_t *plocker)
+mu_locker_destroy (mu_locker_t *plocker)
 {
   if (plocker && *plocker)
     {
@@ -201,7 +246,8 @@ locker_destroy (locker_t *plocker)
     }
 }
 
-int locker_set_flags (locker_t locker, int flags)
+int
+mu_locker_set_flags (mu_locker_t locker, int flags)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -212,7 +258,7 @@ int locker_set_flags (locker_t locker, int flags)
 }
 
 int
-locker_set_expire_time (locker_t locker, int etime)
+mu_locker_set_expire_time (mu_locker_t locker, int etime)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -226,7 +272,7 @@ locker_set_expire_time (locker_t locker, int etime)
 }
 
 int
-locker_set_retries (locker_t locker, int retries)
+mu_locker_set_retries (mu_locker_t locker, int retries)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -240,7 +286,7 @@ locker_set_retries (locker_t locker, int retries)
 }
 
 int
-locker_set_retry_sleep (locker_t locker, int retry_sleep)
+mu_locker_set_retry_sleep (mu_locker_t locker, int retry_sleep)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -254,7 +300,7 @@ locker_set_retry_sleep (locker_t locker, int retry_sleep)
 }
 
 int
-locker_set_external (locker_t locker, const char* program)
+mu_locker_set_external (mu_locker_t locker, const char* program)
 {
   char* p = NULL;
 
@@ -278,7 +324,7 @@ locker_set_external (locker_t locker, const char* program)
 }
 
 int
-locker_get_flags (locker_t locker, int *flags)
+mu_locker_get_flags (mu_locker_t locker, int *flags)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -292,7 +338,7 @@ locker_get_flags (locker_t locker, int *flags)
 }
 
 int
-locker_get_expire_time (locker_t locker, int *ptime)
+mu_locker_get_expire_time (mu_locker_t locker, int *ptime)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -306,7 +352,7 @@ locker_get_expire_time (locker_t locker, int *ptime)
 }
 
 int
-locker_get_retries (locker_t locker, int *retries)
+mu_locker_get_retries (mu_locker_t locker, int *retries)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -320,7 +366,7 @@ locker_get_retries (locker_t locker, int *retries)
 }
 
 int
-locker_get_retry_sleep (locker_t locker, int *retry_sleep)
+mu_locker_get_retry_sleep (mu_locker_t locker, int *retry_sleep)
 {
   if (!locker)
     return MU_ERR_LOCKER_NULL;
@@ -334,7 +380,7 @@ locker_get_retry_sleep (locker_t locker, int *retry_sleep)
 }
 
 int
-locker_lock (locker_t lock)
+mu_locker_lock (mu_locker_t lock)
 {
   int rc;
   int retries = 1;
@@ -380,9 +426,15 @@ locker_lock (locker_t lock)
 
       strcpy (tmp, lock->file);
       p = strrchr (tmp, '/');
-      /* A '/' must be present, if not we'll coredump, and that's
-	 correct! */
-      *p = 0; 
+      if (!p)
+	{
+	  free (tmp);
+	  tmp = strdup (".");
+	  if (!tmp)
+	    return ENOMEM;
+	}
+      else
+	*p = 0; 
 
       if (access (tmp, W_OK))
 	{
@@ -418,7 +470,7 @@ locker_lock (locker_t lock)
 }
 
 int
-locker_touchlock (locker_t lock)
+mu_locker_touchlock (mu_locker_t lock)
 {
   if (!lock)
     return MU_ERR_LOCKER_NULL;
@@ -433,7 +485,7 @@ locker_touchlock (locker_t lock)
 }
 
 int
-locker_unlock (locker_t lock)
+mu_locker_unlock (mu_locker_t lock)
 {
   int rc = 0;
 
@@ -471,7 +523,7 @@ locker_unlock (locker_t lock)
 }
 
 int
-locker_remove_lock (locker_t lock)
+mu_locker_remove_lock (mu_locker_t lock)
 {
   int err;
 
@@ -483,14 +535,14 @@ locker_remove_lock (locker_t lock)
 
   /* Force the reference count to 1 to unlock the file. */
   lock->refcnt = 1;
-  err = locker_unlock (lock);
+  err = mu_locker_unlock (lock);
 
   return err;
 }
 
 /* expire a stale lock (if MU_LOCKER_PID or MU_LOCKER_TIME) */
 static void
-expire_stale_lock (locker_t lock)
+expire_stale_lock (mu_locker_t lock)
 {
   int stale = 0;
   int fd = open (lock->data.dot.dotlock, O_RDONLY);
@@ -608,7 +660,7 @@ check_file_permissions (const char *file)
 
 /* Locker-specific lock/unlock functions */
 int
-_locker_lock_dotlock (locker_t lock)
+_locker_lock_dotlock (mu_locker_t lock)
 {
   char host[MAXHOSTNAMELEN + 1] = "localhost";
   char pid[11];		/* 10 is strlen(2^32 = 4294967296) */
@@ -670,7 +722,7 @@ _locker_lock_dotlock (locker_t lock)
       return errno;
     }
 
-  if ((fd = open (lock->data.dot.dotlock, O_RDONLY)) == -1)
+  if ((fd = open (lock->data.dot.dotlock, O_RDWR)) == -1)
     {
       unlink (lock->data.dot.nfslock);
       return errno;
@@ -701,7 +753,7 @@ _locker_lock_dotlock (locker_t lock)
 }  
 
 int
-_locker_unlock_dotlock (locker_t lock)
+_locker_unlock_dotlock (mu_locker_t lock)
 {
   if (unlink (lock->data.dot.dotlock) == -1)
     {
@@ -718,7 +770,7 @@ _locker_unlock_dotlock (locker_t lock)
 }
 
 int
-_locker_lock_kernel (locker_t lock)
+_locker_lock_kernel (mu_locker_t lock)
 {
   int fd;
   struct flock fl;
@@ -745,7 +797,7 @@ _locker_lock_kernel (locker_t lock)
 }
 
 int
-_locker_unlock_kernel (locker_t lock)
+_locker_unlock_kernel (mu_locker_t lock)
 {
   struct flock fl;
 
@@ -773,10 +825,10 @@ _locker_unlock_kernel (locker_t lock)
 #define DEC_DIGS_PER_INT (sizeof(int) * 8 / 3 + 1)
 
 static int
-lock_external (locker_t l, int lock)
+lock_external (mu_locker_t l, int lock)
 {
   int err = 0;
-  const char *av[6];
+  char *av[6];
   int ac = 0;
   char aforce[3 + DEC_DIGS_PER_INT + 1];
   char aretry[3 + DEC_DIGS_PER_INT + 1];
