@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003, 2004, 
+   2005, 2006 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -37,21 +38,57 @@
 #include <mailutils/errno.h>
 #include <mailutils/mu_auth.h>
 
-const char *mu_path_maildir = MU_PATH_MAILDIR; 
-const char *mu_path_folder_dir = "Mail";
+static char *_default_mail_dir = MU_PATH_MAILDIR;
+static char *_mu_mail_dir;
+static char *_default_folder_dir = "Mail";
+static char *_mu_folder_dir;
+
+int
+mu_set_mail_directory (const char *p)
+{
+  if (_mu_mail_dir != _default_mail_dir)
+    free (_mu_mail_dir);
+  return mu_normalize_mailbox_url (&_mu_mail_dir, p);
+}
+
+void
+mu_set_folder_directory (const char *p)
+{
+  if (_mu_folder_dir != _default_folder_dir)
+    free (_mu_folder_dir);
+  _mu_folder_dir = strdup (p);
+}
+
+const char *
+mu_mail_directory ()
+{
+  if (!_mu_mail_dir)
+    _mu_mail_dir = _default_mail_dir;
+  return _mu_mail_dir;
+}
+
+const char *
+mu_folder_directory ()
+{
+  if (!_mu_folder_dir)
+    _mu_folder_dir = _default_folder_dir;
+  return _mu_folder_dir;
+}
+
+int
+mu_construct_user_mailbox_url (char **pout, const char *name)
+{
+  const char *p = mu_mail_directory ();
+  *pout = malloc (strlen (p) + strlen (name) + 1);
+  if (!*pout)
+    return errno;
+  strcat (strcpy (*pout, p), name);
+  return 0;
+}
 
 /* Is this a security risk?  */
 #define USE_ENVIRON 1
 
-static int
-is_proto (const char *p)
-{
-  for (; *p && *p != '/'; p++)
-    if (*p == ':')
-      return 1;
-  return 0;
-}
-
 static int
 split_shortcut (const char *file, const char pfx[], char **user, char **rest)
 {
@@ -141,11 +178,12 @@ static int
 user_mailbox_name (const char *user, char **mailbox_name)
 {
   char *p;
+  const char *url = mu_mail_directory ();
 
-  p = strchr (mu_path_maildir, ':');
-  if (p && strncmp (mu_path_maildir, "mbox", p - mu_path_maildir))
+  p = strchr (url, ':');
+  if (p && strncmp (url, "mbox", p - url))
     {
-      *mailbox_name = strdup (mu_path_maildir);
+      *mailbox_name = strdup (url);
       return 0;
     }
   
@@ -156,10 +194,9 @@ user_mailbox_name (const char *user, char **mailbox_name)
 
   if (user)
     {
-      *mailbox_name = malloc (strlen (user) + strlen (mu_path_maildir) + 2);
-      if (*mailbox_name == NULL)
-	return ENOMEM;
-      sprintf (*mailbox_name, "%s%s", mu_path_maildir, user);
+      int rc = mu_construct_user_mailbox_url (mailbox_name, user);
+      if (rc)
+	return rc;
     }
   else
     {
@@ -183,6 +220,7 @@ plus_expand (const char *file, char **buf)
   char *user = NULL;
   char *path = NULL;
   char *home;
+  const char *folder_dir = mu_folder_directory ();
   int status, len;
   
   if ((status = split_shortcut (file, "+=", &path, &user)))
@@ -202,17 +240,17 @@ plus_expand (const char *file, char **buf)
       return ENOENT;
     }
 
-  if (mu_path_folder_dir[0] == '/' || is_proto (mu_path_folder_dir))
+  if (folder_dir[0] == '/' || mu_is_proto (folder_dir))
     {
-      len = strlen (mu_path_folder_dir) + strlen (path) + 2;
+      len = strlen (folder_dir) + strlen (path) + 2;
       *buf = malloc (len);
-      sprintf (*buf, "%s/%s", mu_path_folder_dir, path);
+      sprintf (*buf, "%s/%s", folder_dir, path);
     }
   else
     {
-      len = strlen (home) + strlen (mu_path_folder_dir) + strlen (path) + 3;
+      len = strlen (home) + strlen (folder_dir) + strlen (path) + 3;
       *buf = malloc (len);
-      sprintf (*buf, "%s/%s/%s", home, mu_path_folder_dir, path);
+      sprintf (*buf, "%s/%s/%s", home, folder_dir, path);
     }
   (*buf)[len-1] = 0;
   
@@ -222,48 +260,6 @@ plus_expand (const char *file, char **buf)
   return 0;
 }
 
-/* Do ~ , if necessary. */
-static int
-tilde_expand (const char *file, char **buf)
-{
-  char *user = NULL;
-  char *path = NULL;
-  char *home;
-  int status;
-  int len;
-  
-  if ((status = split_shortcut (file, "~", &user, &path)))
-    return status;
-
-  if (!path)
-    {
-      if (user)
-	free (user);
-      return ENOENT;
-    }
-  
-  home = get_homedir (user);
-  if (!home)
-    {
-      free (user);
-      free (path);
-      return MU_ERR_NO_SUCH_USER;
-    }
-
-  free (user); /* not needed anymore */
-      
-  len = strlen (home) + strlen (path) + 2;
-  *buf = malloc (len);
-  if (*buf)
-    {
-      sprintf (*buf, "%s/%s", home, path);
-      (*buf)[len-1] = 0;
-    }
-
-  free (path);
-  return *buf ? 0 : ENOMEM;
-}
-
 static int
 percent_expand (const char *file, char **mbox)
 {
@@ -287,7 +283,7 @@ percent_expand (const char *file, char **mbox)
 }
 
 /* We are trying to be smart about the location of the mail.
-   mailbox_create() is not doing this.
+   mu_mailbox_create() is not doing this.
    %           --> system mailbox for the real uid
    %user       --> system mailbox for the given user
    ~/file      --> /home/user/file
@@ -296,10 +292,11 @@ percent_expand (const char *file, char **mbox)
    =file       --> /home/user/Mail/file
 */
 int
-mailbox_create_default (mailbox_t *pmbox, const char *mail)
+mu_mailbox_create_default (mu_mailbox_t *pmbox, const char *mail)
 {
   char *mbox = NULL;
   char *tmp_mbox = NULL;
+  char *p;
   int status = 0;
 
   /* Sanity.  */
@@ -324,16 +321,22 @@ mailbox_create_default (mailbox_t *pmbox, const char *mail)
         }
     }
 
+  p = mu_tilde_expansion (mail, "/", NULL);
+  if (tmp_mbox)
+    {
+      free (tmp_mbox);
+      tmp_mbox = p;
+    }
+  mail = p;
+  if (!mail)
+    return ENOMEM;
+  
   switch (mail[0])
     {
     case '%':
       status = percent_expand (mail, &mbox);
       break;
       
-    case '~':
-      status = tilde_expand (mail, &mbox);
-      break;
-      
     case '+':
     case '=':
       status = plus_expand (mail, &mbox);
@@ -344,7 +347,7 @@ mailbox_create_default (mailbox_t *pmbox, const char *mail)
       break;
       
     default:
-      if (!is_proto (mail))
+      if (!mu_is_proto (mail))
 	{
 	  tmp_mbox = mu_getcwd();
 	  mbox = malloc (strlen (tmp_mbox) + strlen (mail) + 2);
@@ -361,7 +364,7 @@ mailbox_create_default (mailbox_t *pmbox, const char *mail)
   if (status)
     return status;
   
-  status = mailbox_create (pmbox, mbox);
+  status = mu_mailbox_create (pmbox, mbox);
   free (mbox);
   return status;
 }
