@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2004, 
+   2005, 2006 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +12,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -49,31 +51,32 @@
 #include <mailutils/stream.h>
 #include <mailutils/mu_auth.h>
 #include <mailutils/nls.h>
+#include <mu_umaxtostr.h>
 
 #define MESSAGE_MODIFIED 0x10000;
 
-static int message_read   __P ((stream_t is, char *buf, size_t buflen,
-				off_t off, size_t *pnread ));
-static int message_write  __P ((stream_t os, const char *buf, size_t buflen,
-				off_t off, size_t *pnwrite));
-static int message_get_transport2 __P ((stream_t stream, mu_transport_t *pin, 
-                                       mu_transport_t *pout));
-static int message_sender __P ((envelope_t envelope, char *buf, size_t len,
-				size_t *pnwrite));
-static int message_date   __P ((envelope_t envelope, char *buf, size_t len,
-				size_t *pnwrite));
-static int message_stream_size __P((stream_t stream, off_t *psize));
-static int message_header_fill __P ((header_t header, char *buffer,
-				     size_t buflen, off_t off,
-				     size_t * pnread));
-static int message_body_read __P ((stream_t stream,  char *buffer,
-				   size_t n, off_t off, size_t *pn));
+static int message_read   (mu_stream_t is, char *buf, size_t buflen,
+			   mu_off_t off, size_t *pnread );
+static int message_write  (mu_stream_t os, const char *buf, size_t buflen,
+			   mu_off_t off, size_t *pnwrite);
+static int message_get_transport2 (mu_stream_t stream, mu_transport_t *pin, 
+                                   mu_transport_t *pout);
+static int message_sender (mu_envelope_t envelope, char *buf, size_t len,
+			   size_t *pnwrite);
+static int message_date   (mu_envelope_t envelope, char *buf, size_t len,
+			   size_t *pnwrite);
+static int message_stream_size (mu_stream_t stream, mu_off_t *psize);
+static int message_header_fill (mu_header_t header, char *buffer,
+			        size_t buflen, mu_off_t off,
+				size_t * pnread);
+static int message_body_read (mu_stream_t stream,  char *buffer,
+			      size_t n, mu_off_t off, size_t *pn);
 
-/*  Allocate ressources for the message_t.  */
+/*  Allocate ressources for the mu_message_t.  */
 int
-message_create (message_t *pmsg, void *owner)
+mu_message_create (mu_message_t *pmsg, void *owner)
 {
-  message_t msg;
+  mu_message_t msg;
   int status;
 
   if (pmsg == NULL)
@@ -81,7 +84,7 @@ message_create (message_t *pmsg, void *owner)
   msg = calloc (1, sizeof (*msg));
   if (msg == NULL)
     return ENOMEM;
-  status = monitor_create (&(msg->monitor), 0, msg);
+  status = mu_monitor_create (&(msg->monitor), 0, msg);
   if (status != 0)
     {
       free (msg);
@@ -94,15 +97,15 @@ message_create (message_t *pmsg, void *owner)
 }
 
 void
-message_destroy (message_t *pmsg, void *owner)
+mu_message_destroy (mu_message_t *pmsg, void *owner)
 {
   if (pmsg && *pmsg)
     {
-      message_t msg = *pmsg;
-      monitor_t monitor = msg->monitor;
+      mu_message_t msg = *pmsg;
+      mu_monitor_t monitor = msg->monitor;
       int destroy_lock = 0;
 
-      monitor_wrlock (monitor);
+      mu_monitor_wrlock (monitor);
       msg->ref--;
       if ((msg->owner && msg->owner == owner)
 	  || (msg->owner == NULL && msg->ref <= 0))
@@ -112,65 +115,65 @@ message_destroy (message_t *pmsg, void *owner)
 	  /* FIXME: to be removed since we do not support this event.  */
 	  if (msg->observable)
 	    {
-	      observable_notify (msg->observable, MU_EVT_MESSAGE_DESTROY);
-	      observable_destroy (&(msg->observable), msg);
+	      mu_observable_notify (msg->observable, MU_EVT_MESSAGE_DESTROY);
+	      mu_observable_destroy (&(msg->observable), msg);
 	    }
 
 	  /* Envelope.  */
 	  if (msg->envelope)
-	    envelope_destroy (&(msg->envelope), msg);
+	    mu_envelope_destroy (&(msg->envelope), msg);
 
 	  /* Header.  */
 	  if (msg->header)
-	    header_destroy (&(msg->header), msg);
+	    mu_header_destroy (&(msg->header), msg);
 
 	  /* Body.  */
 	  if (msg->body)
-	    body_destroy (&(msg->body), msg);
+	    mu_body_destroy (&(msg->body), msg);
 
 	  /* Attribute.  */
 	  if (msg->attribute)
-	    attribute_destroy (&(msg->attribute), msg);
+	    mu_attribute_destroy (&(msg->attribute), msg);
 
 	  /* Stream.  */
 	  if (msg->stream)
-	    stream_destroy (&(msg->stream), msg);
+	    mu_stream_destroy (&(msg->stream), msg);
 
 	  /*  Mime.  */
 	  if (msg->mime)
-	    mime_destroy (&(msg->mime));
+	    mu_mime_destroy (&(msg->mime));
 
 	  /* Loose the owner.  */
 	  msg->owner = NULL;
 
 	  /* Mailbox maybe created floating i.e they were created
 	     implicitely by the message when doing something like:
-	     message_create (&msg, "pop://localhost/msgno=2", NULL);
-	     message_create (&msg, "imap://localhost/alain;uid=xxxxx", NULL);
+	     mu_message_create (&msg, "pop://localhost/msgno=2", NULL);
+	     mu_message_create (&msg, "imap://localhost/alain;uid=xxxxx", NULL);
 	     althought the semantics about this is still flaky we our
 	     making some provisions here for it.
 	     if (msg->floating_mailbox && msg->mailbox)
-	     mailbox_destroy (&(msg->mailbox));
+	     mu_mailbox_destroy (&(msg->mailbox));
 	  */
 
 	  if (msg->ref == 0)
 	    free (msg);
 	}
-      monitor_unlock (monitor);
+      mu_monitor_unlock (monitor);
       if (destroy_lock)
-	monitor_destroy (&monitor, msg);
+	mu_monitor_destroy (&monitor, msg);
       /* Loose the link */
       *pmsg = NULL;
     }
 }
 
 int
-message_create_copy (message_t *to, message_t from)
+mu_message_create_copy (mu_message_t *to, mu_message_t from)
 {
   int status = 0;
-  stream_t fromstr = NULL;
-  stream_t tostr = NULL;
-  off_t off = 0;
+  mu_stream_t fromstr = NULL;
+  mu_stream_t tostr = NULL;
+  mu_off_t off = 0;
   size_t n = 0;
   char buf[512];
 
@@ -179,78 +182,78 @@ message_create_copy (message_t *to, message_t from)
   if (!from)
     return EINVAL;
 
-  if((status = message_create (to, NULL)))
+  if((status = mu_message_create (to, NULL)))
     return status;
 
-  message_get_stream (from, &fromstr);
-  message_get_stream (*to, &tostr);
+  mu_message_get_stream (from, &fromstr);
+  mu_message_get_stream (*to, &tostr);
 
   while (
-      (status = stream_readline (fromstr, buf, sizeof(buf), off, &n)) == 0
+      (status = mu_stream_readline (fromstr, buf, sizeof(buf), off, &n)) == 0
 	 &&
       n > 0
       )
     {
-      stream_write (tostr, buf, n, off, NULL);
+      mu_stream_write (tostr, buf, n, off, NULL);
       off += n;
     }
 
   if(status)
-    message_destroy(to, NULL);
+    mu_message_destroy(to, NULL);
   
   return status;
 }
 
 int
-message_ref (message_t msg)
+mu_message_ref (mu_message_t msg)
 {
   if (msg)
     {
-      monitor_wrlock (msg->monitor);
+      mu_monitor_wrlock (msg->monitor);
       msg->ref++;
-      monitor_unlock (msg->monitor);
+      mu_monitor_unlock (msg->monitor);
     }
   return 0;
 }
 
 void *
-message_get_owner (message_t msg)
+mu_message_get_owner (mu_message_t msg)
 {
   return (msg == NULL) ? NULL : msg->owner;
 }
 
 int
-message_is_modified (message_t msg)
+mu_message_is_modified (mu_message_t msg)
 {
   int mod = 0;
   if (msg)
     {
-      mod |= header_is_modified (msg->header);
-      mod |= attribute_is_modified (msg->attribute);
-      mod |= body_is_modified (msg->body);
+      mod |= mu_header_is_modified (msg->header);
+      mod |= mu_attribute_is_modified (msg->attribute);
+      mod |= mu_body_is_modified (msg->body);
       mod |= msg->flags;
     }
   return mod;
 }
 
 int
-message_clear_modified (message_t msg)
+mu_message_clear_modified (mu_message_t msg)
 {
   if (msg)
     {
       if (msg->header)
-	header_clear_modified (msg->header);
+	mu_header_clear_modified (msg->header);
       if (msg->attribute)
-	attribute_clear_modified (msg->attribute);
+	mu_attribute_clear_modified (msg->attribute);
       if (msg->body)
-	body_clear_modified (msg->body);
+	mu_body_clear_modified (msg->body);
       msg->flags &= ~MESSAGE_MODIFIED;
     }
   return 0;
 }
 
 int
-message_get_mailbox (message_t msg, mailbox_t *pmailbox)
+mu_message_get_mailbox (mu_message_t msg, mu_mailbox_t *pmailbox)
 {
   if (msg == NULL)
     return EINVAL;
@@ -261,7 +264,7 @@ message_get_mailbox (message_t msg, mailbox_t *pmailbox)
 }
 
 int
-message_set_mailbox (message_t msg, mailbox_t mailbox, void *owner)
+mu_message_set_mailbox (mu_message_t msg, mu_mailbox_t mailbox, void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -272,7 +275,7 @@ message_set_mailbox (message_t msg, mailbox_t mailbox, void *owner)
 }
 
 int
-message_get_header (message_t msg, header_t *phdr)
+mu_message_get_header (mu_message_t msg, mu_header_t *phdr)
 {
   if (msg == NULL)
     return EINVAL;
@@ -282,16 +285,16 @@ message_get_header (message_t msg, header_t *phdr)
   /* Is it a floating mesg */
   if (msg->header == NULL)
     {
-      header_t header;
-      int status = header_create (&header, NULL, 0, msg);
+      mu_header_t header;
+      int status = mu_header_create (&header, NULL, 0, msg);
       if (status != 0)
 	return status;
       if (msg->stream)
 	{
 	  /* Was it created by us?  */
-	  message_t mesg = stream_get_owner (msg->stream);
+	  mu_message_t mesg = mu_stream_get_owner (msg->stream);
 	  if (mesg != msg)
-	    header_set_fill (header, message_header_fill, msg);
+	    mu_header_set_fill (header, message_header_fill, msg);
 	}
       msg->header = header;
     }
@@ -300,7 +303,7 @@ message_get_header (message_t msg, header_t *phdr)
 }
 
 int
-message_set_header (message_t msg, header_t hdr, void *owner)
+mu_message_set_header (mu_message_t msg, mu_header_t hdr, void *owner)
 {
   if (msg == NULL )
     return EINVAL;
@@ -309,14 +312,14 @@ message_set_header (message_t msg, header_t hdr, void *owner)
   /* Make sure we destroy the old if it was own by the mesg */
   /* FIXME:  I do not know if somebody has already a ref on this ? */
   if (msg->header)
-    header_destroy (&(msg->header), msg);
+    mu_header_destroy (&(msg->header), msg);
   msg->header = hdr;
   msg->flags |= MESSAGE_MODIFIED;
   return 0;
 }
 
 int
-message_get_body (message_t msg, body_t *pbody)
+mu_message_get_body (mu_message_t msg, mu_body_t *pbody)
 {
   if (msg == NULL)
     return EINVAL;
@@ -326,28 +329,28 @@ message_get_body (message_t msg, body_t *pbody)
   /* Is it a floating mesg.  */
   if (msg->body == NULL)
     {
-      body_t body;
-      int status = body_create (&body, msg);
+      mu_body_t body;
+      int status = mu_body_create (&body, msg);
       if (status != 0)
 	return status;
       /* If a stream is already set use it to create the body stream.  */
       if (msg->stream)
 	{
 	  /* Was it created by us?  */
-	  message_t mesg = stream_get_owner (msg->stream);
+	  mu_message_t mesg = mu_stream_get_owner (msg->stream);
 	  if (mesg != msg)
 	    {
-	      stream_t stream;
+	      mu_stream_t stream;
 	      int flags = 0;
-	      stream_get_flags (msg->stream, &flags);
-	      if ((status = stream_create (&stream, flags, body)) != 0)
+	      mu_stream_get_flags (msg->stream, &flags);
+	      if ((status = mu_stream_create (&stream, flags, body)) != 0)
 		{
-		  body_destroy (&body, msg);
+		  mu_body_destroy (&body, msg);
 		  return status;
 		}
-	      stream_set_read (stream, message_body_read, body);
-	      stream_setbufsiz (stream, 128);
-	      body_set_stream (body, stream, msg);
+	      mu_stream_set_read (stream, message_body_read, body);
+	      mu_stream_setbufsiz (stream, 128);
+	      mu_body_set_stream (body, stream, msg);
 	    }
 	}
       msg->body = body;
@@ -357,7 +360,7 @@ message_get_body (message_t msg, body_t *pbody)
 }
 
 int
-message_set_body (message_t msg, body_t body, void *owner)
+mu_message_set_body (mu_message_t msg, mu_body_t body, void *owner)
 {
   if (msg == NULL )
     return EINVAL;
@@ -366,14 +369,14 @@ message_set_body (message_t msg, body_t body, void *owner)
   /* Make sure we destoy the old if it was own by the mesg.  */
   /* FIXME:  I do not know if somebody has already a ref on this ? */
   if (msg->body)
-    body_destroy (&(msg->body), msg);
+    mu_body_destroy (&(msg->body), msg);
   msg->body = body;
   msg->flags |= MESSAGE_MODIFIED;
   return 0;
 }
 
 int
-message_set_stream (message_t msg, stream_t stream, void *owner)
+mu_message_set_stream (mu_message_t msg, mu_stream_t stream, void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -382,14 +385,14 @@ message_set_stream (message_t msg, stream_t stream, void *owner)
   /* Make sure we destoy the old if it was own by the mesg.  */
   /* FIXME:  I do not know if somebody has already a ref on this ? */
   if (msg->stream)
-    stream_destroy (&(msg->stream), msg);
+    mu_stream_destroy (&(msg->stream), msg);
   msg->stream = stream;
   msg->flags |= MESSAGE_MODIFIED;
   return 0;
 }
 
 int
-message_get_stream (message_t msg, stream_t *pstream)
+mu_message_get_stream (mu_message_t msg, mu_stream_t *pstream)
 {
   if (msg == NULL)
     return EINVAL;
@@ -398,16 +401,16 @@ message_get_stream (message_t msg, stream_t *pstream)
 
   if (msg->stream == NULL)
     {
-      stream_t stream;
+      mu_stream_t stream;
       int status;
-      status = stream_create (&stream, MU_STREAM_RDWR, msg);
+      status = mu_stream_create (&stream, MU_STREAM_RDWR, msg);
       if (status != 0)
 	return status;
-      stream_set_read (stream, message_read, msg);
-      stream_set_write (stream, message_write, msg);
-      stream_set_get_transport2 (stream, message_get_transport2, msg);
-      stream_set_size (stream, message_stream_size, msg);
-      stream_set_flags (stream, MU_STREAM_RDWR);
+      mu_stream_set_read (stream, message_read, msg);
+      mu_stream_set_write (stream, message_write, msg);
+      mu_stream_set_get_transport2 (stream, message_get_transport2, msg);
+      mu_stream_set_size (stream, message_stream_size, msg);
+      mu_stream_set_flags (stream, MU_STREAM_RDWR);
       msg->stream = stream;
     }
 
@@ -416,8 +419,8 @@ message_get_stream (message_t msg, stream_t *pstream)
 }
 
 int
-message_set_lines (message_t msg, int (*_lines)
-		   (message_t, size_t *), void *owner)
+mu_message_set_lines (mu_message_t msg, int (*_lines)
+		   (mu_message_t, size_t *), void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -428,7 +431,7 @@ message_set_lines (message_t msg, int (*_lines)
 }
 
 int
-message_lines (message_t msg, size_t *plines)
+mu_message_lines (mu_message_t msg, size_t *plines)
 {
   size_t hlines, blines;
   int ret = 0;
@@ -441,16 +444,16 @@ message_lines (message_t msg, size_t *plines)
   if (plines)
     {
       hlines = blines = 0;
-      if ( ( ret = header_lines (msg->header, &hlines) ) == 0 )
-	      ret = body_lines (msg->body, &blines);
+      if ( ( ret = mu_header_lines (msg->header, &hlines) ) == 0 )
+	      ret = mu_body_lines (msg->body, &blines);
       *plines = hlines + blines;
     }
   return ret;
 }
 
 int
-message_set_size (message_t msg, int (*_size)
-		  (message_t, size_t *), void *owner)
+mu_message_set_size (mu_message_t msg, int (*_size)
+		  (mu_message_t, size_t *), void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -461,7 +464,7 @@ message_set_size (message_t msg, int (*_size)
 }
 
 int
-message_size (message_t msg, size_t *psize)
+mu_message_size (mu_message_t msg, size_t *psize)
 {
   size_t hsize, bsize;
   int ret = 0;
@@ -473,21 +476,21 @@ message_size (message_t msg, size_t *psize)
     return msg->_size (msg, psize);
   if (psize)
     {
-      header_t hdr = NULL;
-      body_t body = NULL;
+      mu_header_t hdr = NULL;
+      mu_body_t body = NULL;
       
       hsize = bsize = 0;
-      message_get_header (msg, &hdr);
-      message_get_body (msg, &body);
-      if ( ( ret = header_size (hdr, &hsize) ) == 0 )
-	ret = body_size (body, &bsize);
+      mu_message_get_header (msg, &hdr);
+      mu_message_get_body (msg, &body);
+      if ( ( ret = mu_header_size (hdr, &hsize) ) == 0 )
+	ret = mu_body_size (body, &bsize);
       *psize = hsize + bsize;
     }
   return ret;
 }
 
 int
-message_get_envelope (message_t msg, envelope_t *penvelope)
+mu_message_get_envelope (mu_message_t msg, mu_envelope_t *penvelope)
 {
   if (msg == NULL)
     return EINVAL;
@@ -496,12 +499,12 @@ message_get_envelope (message_t msg, envelope_t *penvelope)
 
   if (msg->envelope == NULL)
     {
-      envelope_t envelope;
-      int status = envelope_create (&envelope, msg);
+      mu_envelope_t envelope;
+      int status = mu_envelope_create (&envelope, msg);
       if (status != 0)
 	return status;
-      envelope_set_sender (envelope, message_sender, msg);
-      envelope_set_date (envelope, message_date, msg);
+      mu_envelope_set_sender (envelope, message_sender, msg);
+      mu_envelope_set_date (envelope, message_date, msg);
       msg->envelope = envelope;
     }
   *penvelope = msg->envelope;
@@ -509,21 +512,21 @@ message_get_envelope (message_t msg, envelope_t *penvelope)
 }
 
 int
-message_set_envelope (message_t msg, envelope_t envelope, void *owner)
+mu_message_set_envelope (mu_message_t msg, mu_envelope_t envelope, void *owner)
 {
   if (msg == NULL)
     return EINVAL;
   if (msg->owner != owner)
     return EACCES;
   if (msg->envelope)
-    envelope_destroy (&(msg->envelope), msg);
+    mu_envelope_destroy (&(msg->envelope), msg);
   msg->envelope = envelope;
   msg->flags |= MESSAGE_MODIFIED;
   return 0;
 }
 
 int
-message_get_attribute (message_t msg, attribute_t *pattribute)
+mu_message_get_attribute (mu_message_t msg, mu_attribute_t *pattribute)
 {
   if (msg == NULL)
     return EINVAL;
@@ -531,8 +534,8 @@ message_get_attribute (message_t msg, attribute_t *pattribute)
     return MU_ERR_OUT_PTR_NULL;
   if (msg->attribute == NULL)
     {
-      attribute_t attribute;
-      int status = attribute_create (&attribute, msg);
+      mu_attribute_t attribute;
+      int status = mu_attribute_create (&attribute, msg);
       if (status != 0)
 	return status;
       msg->attribute = attribute;
@@ -542,21 +545,21 @@ message_get_attribute (message_t msg, attribute_t *pattribute)
 }
 
 int
-message_set_attribute (message_t msg, attribute_t attribute, void *owner)
+mu_message_set_attribute (mu_message_t msg, mu_attribute_t attribute, void *owner)
 {
   if (msg == NULL)
    return EINVAL;
   if (msg->owner != owner)
     return EACCES;
   if (msg->attribute)
-    attribute_destroy (&(msg->attribute), owner);
+    mu_attribute_destroy (&(msg->attribute), owner);
   msg->attribute = attribute;
   msg->flags |= MESSAGE_MODIFIED;
   return 0;
 }
 
 int
-message_get_uid (message_t msg, size_t *puid)
+mu_message_get_uid (mu_message_t msg, size_t *puid)
 {
   if (msg == NULL)
     return EINVAL;
@@ -567,9 +570,9 @@ message_get_uid (message_t msg, size_t *puid)
 }
 
 int
-message_get_uidl (message_t msg, char *buffer, size_t buflen, size_t *pwriten)
+mu_message_get_uidl (mu_message_t msg, char *buffer, size_t buflen, size_t *pwriten)
 {
-  header_t header = NULL;
+  mu_header_t header = NULL;
   size_t n = 0;
   int status;
 
@@ -587,8 +590,8 @@ message_get_uidl (message_t msg, char *buffer, size_t buflen, size_t *pwriten)
 
   /* Be compatible with Qpopper ? qppoper saves the UIDL in "X-UIDL".
      We generate a chksum and save it in the header.  */
-  message_get_header (msg, &header);
-  status = header_get_value (header, "X-UIDL", buffer, buflen, &n);
+  mu_message_get_header (msg, &header);
+  status = mu_header_get_value (header, "X-UIDL", buffer, buflen, &n);
   if (status == 0 && n > 0)
     {
       /* FIXME: Is this necessary ? I did not see so far a x-uidl message
@@ -613,31 +616,32 @@ message_get_uidl (message_t msg, char *buffer, size_t buflen, size_t *pwriten)
   else
     {
       size_t uid = 0;
-      MD5_CTX md5context;
-      stream_t stream = NULL;
+      struct md5_ctx md5context;
+      mu_stream_t stream = NULL;
       char buf[1024];
-      off_t offset = 0;
+      mu_off_t offset = 0;
       unsigned char md5digest[16];
       char *tmp;
       n = 0;
-      message_get_uid (msg, &uid);
-      message_get_stream (msg, &stream);
-      MD5Init (&md5context);
-      while (stream_read (stream, buf, sizeof (buf), offset, &n) == 0
+      mu_message_get_uid (msg, &uid);
+      mu_message_get_stream (msg, &stream);
+      md5_init_ctx (&md5context);
+      while (mu_stream_read (stream, buf, sizeof (buf), offset, &n) == 0
 	     && n > 0)
 	{
-	  MD5Update (&md5context, buf, n);
+	  md5_process_bytes (buf, n, &md5context);
 	  offset += n;
 	}
-      MD5Final (md5digest, &md5context);
+      md5_finish_ctx (&md5context, md5digest);
       tmp = buf;
       for (n = 0; n < 16; n++, tmp += 2)
 	sprintf (tmp, "%02x", md5digest[n]);
       *tmp = '\0';
       /* POP3 rfc says that an UID should not be longer than 70.  */
-      snprintf (buf + 32, 70, ".%lu.%u", (unsigned long)time (NULL), uid);
+      snprintf (buf + 32, 70, ".%lu.%s", (unsigned long)time (NULL), 
+                mu_umaxtostr (0, uid));
 
-      header_set_value (header, "X-UIDL", buf, 1);
+      mu_header_set_value (header, "X-UIDL", buf, 1);
       buflen--; /* leave space for the NULL.  */
       strncpy (buffer, buf, buflen)[buflen] = '\0';
     }
@@ -645,7 +649,7 @@ message_get_uidl (message_t msg, char *buffer, size_t buflen, size_t *pwriten)
 }
 
 int
-message_set_uid (message_t msg, int (*_get_uid) __P ((message_t, size_t *)),
+mu_message_set_uid (mu_message_t msg, int (*_get_uid) (mu_message_t, size_t *),
 		 void *owner)
 {
   if (msg == NULL)
@@ -657,8 +661,9 @@ message_set_uid (message_t msg, int (*_get_uid) __P ((message_t, size_t *)),
 }
 
 int
-message_set_uidl (message_t msg, int (* _get_uidl)
-		  __P ((message_t, char *, size_t, size_t *)), void *owner)
+mu_message_set_uidl (mu_message_t msg,
+		  int (* _get_uidl) (mu_message_t, char *, size_t, size_t *),
+		  void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -669,8 +674,9 @@ message_set_uidl (message_t msg, int (* _get_uidl)
 }
 
 int
-message_set_is_multipart (message_t msg, int (*_is_multipart)
-			  __P ((message_t, int *)), void *owner)
+mu_message_set_is_multipart (mu_message_t msg,
+			  int (*_is_multipart) (mu_message_t, int *),
+			  void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -681,7 +687,7 @@ message_set_is_multipart (message_t msg, int (*_is_multipart)
 }
 
 int
-message_is_multipart (message_t msg, int *pmulti)
+mu_message_is_multipart (mu_message_t msg, int *pmulti)
 {
   if (msg && pmulti)
     {
@@ -689,17 +695,17 @@ message_is_multipart (message_t msg, int *pmulti)
 	return msg->_is_multipart (msg, pmulti);
       if (msg->mime == NULL)
 	{
-	  int status = mime_create (&(msg->mime), msg, 0);
+	  int status = mu_mime_create (&(msg->mime), msg, 0);
 	  if (status != 0)
 	    return 0;
 	}
-      *pmulti = mime_is_multipart(msg->mime);
+      *pmulti = mu_mime_is_multipart(msg->mime);
     }
   return 0;
 }
 
 int
-message_get_num_parts (message_t msg, size_t *pparts)
+mu_message_get_num_parts (mu_message_t msg, size_t *pparts)
 {
   if (msg == NULL || pparts == NULL)
     return EINVAL;
@@ -709,16 +715,17 @@ message_get_num_parts (message_t msg, size_t *pparts)
 
   if (msg->mime == NULL)
     {
-      int status = mime_create (&(msg->mime), msg, 0);
+      int status = mu_mime_create (&(msg->mime), msg, 0);
       if (status != 0)
 	return status;
     }
-  return mime_get_num_parts (msg->mime, pparts);
+  return mu_mime_get_num_parts (msg->mime, pparts);
 }
 
 int
-message_set_get_num_parts (message_t msg, int (*_get_num_parts)
-			   __P ((message_t, size_t *)), void *owner)
+mu_message_set_get_num_parts (mu_message_t msg,
+			   int (*_get_num_parts) (mu_message_t, size_t *),
+			   void *owner)
 {
   if (msg == NULL)
     return EINVAL;
@@ -729,7 +736,7 @@ message_set_get_num_parts (message_t msg, int (*_get_num_parts)
 }
 
 int
-message_get_part (message_t msg, size_t part, message_t *pmsg)
+mu_message_get_part (mu_message_t msg, size_t part, mu_message_t *pmsg)
 {
   if (msg == NULL || pmsg == NULL)
     return EINVAL;
@@ -740,16 +747,16 @@ message_get_part (message_t msg, size_t part, message_t *pmsg)
 
   if (msg->mime == NULL)
     {
-      int status = mime_create (&(msg->mime), msg, 0);
+      int status = mu_mime_create (&(msg->mime), msg, 0);
       if (status != 0)
 	return status;
     }
-  return mime_get_part (msg->mime, part, pmsg);
+  return mu_mime_get_part (msg->mime, part, pmsg);
 }
 
 int
-message_set_get_part (message_t msg, int (*_get_part)
-		      __P ((message_t, size_t, message_t *)),
+mu_message_set_get_part (mu_message_t msg, int (*_get_part)
+		      (mu_message_t, size_t, mu_message_t *),
 		      void *owner)
 {
   if (msg == NULL)
@@ -761,14 +768,14 @@ message_set_get_part (message_t msg, int (*_get_part)
 }
 
 int
-message_get_observable (message_t msg, observable_t *pobservable)
+mu_message_get_observable (mu_message_t msg, mu_observable_t *pobservable)
 {
   if (msg == NULL || pobservable == NULL)
     return EINVAL;
 
   if (msg->observable == NULL)
     {
-      int status = observable_create (&(msg->observable), msg);
+      int status = mu_observable_create (&(msg->observable), msg);
       if (status != 0)
 	return status;
     }
@@ -776,13 +783,13 @@ message_get_observable (message_t msg, observable_t *pobservable)
   return 0;
 }
 
-/* Implements the stream_read () on the message stream.  */
+/* Implements the mu_stream_read () on the message stream.  */
 static int
-message_read (stream_t is, char *buf, size_t buflen,
-	      off_t off, size_t *pnread )
+message_read (mu_stream_t is, char *buf, size_t buflen,
+	      mu_off_t off, size_t *pnread )
 {
-  message_t msg =  stream_get_owner (is);
-  stream_t his, bis;
+  mu_message_t msg =  mu_stream_get_owner (is);
+  mu_stream_t his, bis;
   size_t hread, hsize, bread, bsize;
 
   if (msg == NULL)
@@ -791,8 +798,8 @@ message_read (stream_t is, char *buf, size_t buflen,
   bsize = hsize = bread = hread = 0;
   his = bis = NULL;
 
-  header_size (msg->header, &hsize);
-  body_size (msg->body, &bsize);
+  mu_header_size (msg->header, &hsize);
+  mu_body_size (msg->body, &bsize);
 
   /* On some remote sever (POP) the size of the header and body is not known
      until you start reading them.  So by checking hsize == bsize == 0,
@@ -800,13 +807,13 @@ message_read (stream_t is, char *buf, size_t buflen,
      header.  */
   if ((size_t)off < hsize || (hsize == 0 && bsize == 0))
     {
-      header_get_stream (msg->header, &his);
-      stream_read (his, buf, buflen, off, &hread);
+      mu_header_get_stream (msg->header, &his);
+      mu_stream_read (his, buf, buflen, off, &hread);
     }
   else
     {
-      body_get_stream (msg->body, &bis);
-      stream_read (bis, buf, buflen, off - hsize, &bread);
+      mu_body_get_stream (msg->body, &bis);
+      mu_stream_read (bis, buf, buflen, off - hsize, &bread);
     }
 
   if (pnread)
@@ -814,12 +821,12 @@ message_read (stream_t is, char *buf, size_t buflen,
   return 0;
 }
 
-/* Implements the stream_write () on the message stream.  */
+/* Implements the mu_stream_write () on the message stream.  */
 static int
-message_write (stream_t os, const char *buf, size_t buflen,
-	       off_t off, size_t *pnwrite)
+message_write (mu_stream_t os, const char *buf, size_t buflen,
+	       mu_off_t off, size_t *pnwrite)
 {
-  message_t msg = stream_get_owner (os);
+  mu_message_t msg = mu_stream_get_owner (os);
   int status = 0;
   size_t bufsize = buflen;
 
@@ -838,14 +845,14 @@ message_write (stream_t os, const char *buf, size_t buflen,
     {
       size_t len;
       char *nl;
-      header_t header = NULL;
-      stream_t hstream = NULL;
-      message_get_header (msg, &header);
-      header_get_stream (header, &hstream);
+      mu_header_t header = NULL;
+      mu_stream_t hstream = NULL;
+      mu_message_get_header (msg, &header);
+      mu_header_get_stream (header, &hstream);
       while (!msg->hdr_done && (nl = memchr (buf, '\n', buflen)) != NULL)
 	{
 	  len = nl - buf + 1;
-	  status = stream_write (hstream, buf, len, msg->hdr_buflen, NULL);
+	  status = mu_stream_write (hstream, buf, len, msg->hdr_buflen, NULL);
 	  if (status != 0)
 	    return status;
 	  msg->hdr_buflen += len;
@@ -861,11 +868,11 @@ message_write (stream_t os, const char *buf, size_t buflen,
   /* Message header is not complete but was not a full line.  */
   if (!msg->hdr_done && buflen > 0)
     {
-      header_t header = NULL;
-      stream_t hstream = NULL;
-      message_get_header (msg, &header);
-      header_get_stream (header, &hstream);
-      status = stream_write (hstream, buf, buflen, msg->hdr_buflen, NULL);
+      mu_header_t header = NULL;
+      mu_stream_t hstream = NULL;
+      mu_message_get_header (msg, &header);
+      mu_header_get_stream (header, &hstream);
+      status = mu_stream_write (hstream, buf, buflen, msg->hdr_buflen, NULL);
       if (status != 0)
 	return status;
       msg->hdr_buflen += buflen;
@@ -873,20 +880,20 @@ message_write (stream_t os, const char *buf, size_t buflen,
     }
   else if (buflen > 0) /* In the body.  */
     {
-      stream_t bs;
-      body_t body;
+      mu_stream_t bs;
+      mu_body_t body;
       size_t written = 0;
-      if ((status = message_get_body (msg, &body)) != 0 ||
-	  (status = body_get_stream (msg->body, &bs)) != 0)
+      if ((status = mu_message_get_body (msg, &body)) != 0 ||
+	  (status = mu_body_get_stream (msg->body, &bs)) != 0)
 	{
 	  msg->hdr_buflen = msg->hdr_done = 0;
 	  return status;
 	}
-      if (off < (off_t)msg->hdr_buflen)
+      if (off < (mu_off_t)msg->hdr_buflen)
 	off = 0;
       else
 	off -= msg->hdr_buflen;
-      status = stream_write (bs, buf, buflen, off, &written);
+      status = mu_stream_write (bs, buf, buflen, off, &written);
       buflen -= written;
     }
   if (pnwrite)
@@ -895,11 +902,11 @@ message_write (stream_t os, const char *buf, size_t buflen,
 }
 
 static int
-message_get_transport2 (stream_t stream, mu_transport_t *pin, mu_transport_t *pout)
+message_get_transport2 (mu_stream_t stream, mu_transport_t *pin, mu_transport_t *pout)
 {
-  message_t msg = stream_get_owner (stream);
-  body_t body;
-  stream_t is;
+  mu_message_t msg = mu_stream_get_owner (stream);
+  mu_body_t body;
+  mu_stream_t is;
 
   if (msg == NULL)
     return EINVAL;
@@ -909,7 +916,7 @@ message_get_transport2 (stream_t stream, mu_transport_t *pin, mu_transport_t *po
   /* Probably being lazy, then create a body for the stream.  */
   if (msg->body == NULL)
     {
-      int status = body_create (&body, msg);
+      int status = mu_body_create (&body, msg);
       if (status != 0 )
 	return status;
       msg->body = body;
@@ -917,22 +924,22 @@ message_get_transport2 (stream_t stream, mu_transport_t *pin, mu_transport_t *po
   else
       body = msg->body;
 
-  body_get_stream (body, &is);
-  return stream_get_transport2 (is, pin, pout);
+  mu_body_get_stream (body, &is);
+  return mu_stream_get_transport2 (is, pin, pout);
 }
 
 /* Implements the stream_stream_size () on the message stream.  */
 static int
-message_stream_size (stream_t stream, off_t *psize)
+message_stream_size (mu_stream_t stream, mu_off_t *psize)
 {
-  message_t msg = stream_get_owner (stream);
-  return message_size (msg, (size_t*) psize);
+  mu_message_t msg = mu_stream_get_owner (stream);
+  return mu_message_size (msg, (size_t*) psize);
 }
 
 static int
-message_date (envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
+message_date (mu_envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
 {
-  message_t msg = envelope_get_owner (envelope);
+  mu_message_t msg = mu_envelope_get_owner (envelope);
   time_t t;
   size_t n;
 
@@ -941,30 +948,28 @@ message_date (envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
 
   /* FIXME: extract the time from "Date:".  */
 
-  /* Catch all.  */
-  /* FIXME: ctime() is not thread safe use strftime().  */
-  t = time (NULL);
-  n = strlen (ctime (&t));
-
   if (buf == NULL || len == 0)
     {
-      if (pnwrite)
-	*pnwrite = n;
-      return 0;
+      n = MU_ENVELOPE_DATE_LENGTH;
+    }
+  else
+    {
+      char tmpbuf[MU_ENVELOPE_DATE_LENGTH+1];
+      t = time (NULL);
+      n = mu_strftime (tmpbuf, sizeof tmpbuf, 
+                       MU_ENVELOPE_DATE_FORMAT, localtime (&t));
+      n = mu_cpystr (buf, tmpbuf, len);
     }
-  n = (n > len) ? len : n;
-  strncpy (buf, ctime (&t), n);
-  buf [n] = '\0';
   if (pnwrite)
     *pnwrite = n;
   return 0;
 }
 
 static int
-message_sender (envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
+message_sender (mu_envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
 {
-  message_t msg = envelope_get_owner (envelope);
-  header_t header = NULL;
+  mu_message_t msg = mu_envelope_get_owner (envelope);
+  mu_header_t header = NULL;
   size_t n = 0;
   int status;
 
@@ -972,20 +977,20 @@ message_sender (envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
     return EINVAL;
 
   /* Can it be extracted from the From:  */
-  message_get_header (msg, &header);
-  status = header_get_value (header, MU_HEADER_FROM, NULL, 0, &n);
+  mu_message_get_header (msg, &header);
+  status = mu_header_get_value (header, MU_HEADER_FROM, NULL, 0, &n);
   if (status == 0 && n != 0)
     {
       char *sender;
-      address_t address = NULL;
+      mu_address_t address = NULL;
       sender = calloc (1, n + 1);
       if (sender == NULL)
 	return ENOMEM;
-      header_get_value (header, MU_HEADER_FROM, sender, n + 1, NULL);
-      if (address_create (&address, sender) == 0)
-	address_get_email (address, 1, buf, n + 1, pnwrite);
+      mu_header_get_value (header, MU_HEADER_FROM, sender, n + 1, NULL);
+      if (mu_address_create (&address, sender) == 0)
+	mu_address_get_email (address, 1, buf, n + 1, pnwrite);
       free (sender);
-      address_destroy (&address);
+      mu_address_destroy (&address);
       return 0;
     }
   else if (status == EAGAIN)
@@ -1013,12 +1018,12 @@ message_sender (envelope_t envelope, char *buf, size_t len, size_t *pnwrite)
 }
 
 static int
-message_header_fill (header_t header, char *buffer, size_t buflen,
-		     off_t off, size_t * pnread)
+message_header_fill (mu_header_t header, char *buffer, size_t buflen,
+		     mu_off_t off, size_t * pnread)
 {
   int status = 0;
-  message_t msg = header_get_owner (header);
-  stream_t stream = NULL;
+  mu_message_t msg = mu_header_get_owner (header);
+  mu_stream_t stream = NULL;
   size_t nread = 0;
 
   /* Noop.  */
@@ -1031,11 +1036,11 @@ message_header_fill (header_t header, char *buffer, size_t buflen,
 
   if (!msg->hdr_done)
     {
-      status = message_get_stream (msg, &stream);
+      status = mu_message_get_stream (msg, &stream);
       if (status == 0)
 	{
 	  /* Position the file pointer and the buffer.  */
-	  status = stream_readline (stream, buffer, buflen, off, &nread);
+	  status = mu_stream_readline (stream, buffer, buflen, off, &nread);
 	  /* Detect the end of the headers. */
 	  if (nread  && buffer[0] == '\n' && buffer[1] == '\0')
 	    {
@@ -1052,23 +1057,23 @@ message_header_fill (header_t header, char *buffer, size_t buflen,
 }
 
 static int
-message_body_read (stream_t stream,  char *buffer, size_t n, off_t off,
+message_body_read (mu_stream_t stream,  char *buffer, size_t n, mu_off_t off,
 		   size_t *pn)
 {
-  body_t body = stream_get_owner (stream);
-  message_t msg = body_get_owner (body);
+  mu_body_t body = mu_stream_get_owner (stream);
+  mu_message_t msg = mu_body_get_owner (body);
   size_t nread = 0;
-  header_t header = NULL;
-  stream_t bstream = NULL;
+  mu_header_t header = NULL;
+  mu_stream_t bstream = NULL;
   size_t size = 0;
   int status;
 
-  message_get_header (msg, &header);
-  status = header_size (msg->header, &size);
+  mu_message_get_header (msg, &header);
+  status = mu_header_size (msg->header, &size);
   if (status == 0)
     {
-      message_get_stream (msg, &bstream);
-      status = stream_read (bstream, buffer, n, size + off, &nread);
+      mu_message_get_stream (msg, &bstream);
+      status = mu_stream_read (bstream, buffer, n, size + off, &nread);
     }
   if (pn)
     *pn = nread;
@@ -1076,55 +1081,55 @@ message_body_read (stream_t stream,  char *buffer, size_t n, off_t off,
 }
 
 int
-message_save_to_mailbox (message_t msg, ticket_t ticket, mu_debug_t debug,
+mu_message_save_to_mailbox (mu_message_t msg, mu_ticket_t ticket, mu_debug_t debug,
 			 const char *toname)
 {
   int rc = 0;
-  mailbox_t to = 0;
+  mu_mailbox_t to = 0;
 
-  if ((rc = mailbox_create_default (&to, toname)))
+  if ((rc = mu_mailbox_create_default (&to, toname)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      _("mailbox_create_default (%s) failed: %s\n"), toname,
+		      _("mu_mailbox_create_default (%s) failed: %s\n"), toname,
 		      mu_strerror (rc));
       goto end;
     }
 
-  if (debug && (rc = mailbox_set_debug (to, debug)))
+  if (debug && (rc = mu_mailbox_set_debug (to, debug)))
 	goto end;
 
   if (ticket)
     {
-      folder_t folder = NULL;
+      mu_folder_t folder = NULL;
 
-      if ((rc = mailbox_get_folder (to, &folder)))
+      if ((rc = mu_mailbox_get_folder (to, &folder)))
 	goto end;
 
       /* FIXME: not all mailboxes have folders, thus this hack. */
       if (folder)
 	{
-	  authority_t auth = NULL;
-	  if ((rc = folder_get_authority (folder, &auth)))
+	  mu_authority_t auth = NULL;
+	  if ((rc = mu_folder_get_authority (folder, &auth)))
 	    goto end;
 
 	  /* FIXME: not all folders have authentication, thus this hack. */
-	  if (auth && (rc = authority_set_ticket (auth, ticket)))
+	  if (auth && (rc = mu_authority_set_ticket (auth, ticket)))
 	    goto end;
 	}
     }
 
-  if ((rc = mailbox_open (to, MU_STREAM_WRITE | MU_STREAM_CREAT)))
+  if ((rc = mu_mailbox_open (to, MU_STREAM_WRITE | MU_STREAM_CREAT)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      _("mailbox_open (%s) failed: %s\n"), toname,
+		      _("mu_mailbox_open (%s) failed: %s\n"), toname,
 		      mu_strerror (rc));
       goto end;
     }
 
-  if ((rc = mailbox_append_message (to, msg)))
+  if ((rc = mu_mailbox_append_message (to, msg)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      _("mailbox_append_message (%s) failed: %s\n"), toname,
+		      _("mu_mailbox_append_message (%s) failed: %s\n"), toname,
 		      mu_strerror (rc));
       goto end;
     }
@@ -1133,19 +1138,19 @@ end:
 
   if (!rc)
     {
-      if ((rc = mailbox_close (to)))
+      if ((rc = mu_mailbox_close (to)))
 	{
 	  mu_debug_print (debug, MU_DEBUG_TRACE,
-			  _("mailbox_close (%s) failed: %s\n"), toname,
+			  _("mu_mailbox_close (%s) failed: %s\n"), toname,
 			  mu_strerror (rc));
 	}
     }
   else
     {
-      mailbox_close (to);
+      mu_mailbox_close (to);
     }
 
-  mailbox_destroy (&to);
+  mu_mailbox_destroy (&to);
 
   return rc;
 }
