@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -43,11 +44,12 @@
 #endif
 
 /* TODO:
- *  Need to prevent re-entry into mime lib, but allow non-blocking re-entry into lib.
+ *  Need to prevent re-entry into mime lib, but allow non-blocking re-entry
+ *  into lib.
  */
 
 static int
-_mime_is_multipart_digest (mime_t mime)
+_mime_is_multipart_digest (mu_mime_t mime)
 {
   if (mime->content_type)
     return (strncasecmp
@@ -57,12 +59,12 @@ _mime_is_multipart_digest (mime_t mime)
 }
 
 static int
-_mime_append_part (mime_t mime, message_t msg, int offset, int len, int lines)
+_mime_append_part (mu_mime_t mime, mu_message_t msg, int offset, int len, int lines)
 {
   struct _mime_part *mime_part, **part_arr;
-  int ret;
-  size_t size;
-  header_t hdr;
+  int             ret;
+  size_t          size;
+  mu_header_t        hdr;
 
   if ((mime_part = calloc (1, sizeof (*mime_part))) == NULL)
     return ENOMEM;
@@ -82,17 +84,17 @@ _mime_append_part (mime_t mime, message_t msg, int offset, int len, int lines)
   mime->mtp_parts[mime->nmtp_parts++] = mime_part;
   if (msg == NULL)
     {
-      if ((ret = message_create (&(mime_part->msg), mime_part)) == 0)
+      if ((ret = mu_message_create (&(mime_part->msg), mime_part)) == 0)
 	{
 	  if ((ret =
-	       header_create (&hdr, mime->header_buf,
-			      mime->header_length, mime_part->msg)) != 0)
+	       mu_header_create (&hdr, mime->header_buf,
+				 mime->header_length, mime_part->msg)) != 0)
 	    {
-	      message_destroy (&mime_part->msg, mime_part);
+	      mu_message_destroy (&mime_part->msg, mime_part);
 	      free (mime_part);
 	      return ret;
 	    }
-	  message_set_header (mime_part->msg, hdr, mime_part);
+	  mu_message_set_header (mime_part->msg, hdr, mime_part);
 	}
       else
 	{
@@ -101,14 +103,15 @@ _mime_append_part (mime_t mime, message_t msg, int offset, int len, int lines)
 	}
       mime->header_length = 0;
       if ((ret =
-	   header_get_value (hdr, MU_HEADER_CONTENT_TYPE, NULL,
-			     0, &size)) != 0 || size == 0)
+	   mu_header_get_value (hdr, MU_HEADER_CONTENT_TYPE, NULL,
+				0, &size)) != 0 || size == 0)
 	{
 	  if (_mime_is_multipart_digest (mime))
-	    header_set_value (hdr,
-			      MU_HEADER_CONTENT_TYPE, "message/rfc822", 0);
+	    mu_header_set_value (hdr,
+				 MU_HEADER_CONTENT_TYPE, "message/rfc822", 0);
 	  else
-	    header_set_value (hdr, MU_HEADER_CONTENT_TYPE, "text/plain", 0);
+	    mu_header_set_value (hdr, MU_HEADER_CONTENT_TYPE, "text/plain",
+				 0);
 	}
       mime_part->len = len;
       mime_part->lines = lines;
@@ -116,9 +119,9 @@ _mime_append_part (mime_t mime, message_t msg, int offset, int len, int lines)
     }
   else
     {
-      message_ref (msg);
-      message_size (msg, &mime_part->len);
-      message_lines (msg, &mime_part->lines);
+      mu_message_ref (msg);
+      mu_message_size (msg, &mime_part->len);
+      mu_message_lines (msg, &mime_part->lines);
       if (mime->nmtp_parts > 1)
 	mime_part->offset = mime->mtp_parts[mime->nmtp_parts - 2]->len;
       mime_part->msg = msg;
@@ -147,7 +150,8 @@ _strttrim (char *str)
   return (str);
 }
 
-char *_strtrim (char *str);
+char           *_strtrim (char *str);
+
 #define _strtrim(str) _strltrim(_strttrim(str))
 
 #define _ISSPECIAL(c) ( \
@@ -159,8 +163,8 @@ char *_strtrim (char *str);
 static void
 _mime_munge_content_header (char *field_body)
 {
-  char *p, *e, *str = field_body;
-  int quoted = 0;
+  char           *p, *e, *str = field_body;
+  int             quoted = 0;
 
   _strtrim (field_body);
 
@@ -170,7 +174,7 @@ _mime_munge_content_header (char *field_body)
     {
       p = e;
       e++;
-      while (*e && isspace ((unsigned char) *e))	/* remove space upto param */
+      while (*e && isspace ((unsigned char) *e)) /* remove space up to param */
 	e++;
       memmove (p + 1, e, strlen (e) + 1);
       e = p + 1;
@@ -184,7 +188,7 @@ _mime_munge_content_header (char *field_body)
 	{
 	  if (*e == '\\')
 	    {			/* escaped */
-	      memmove (e, e + 1, strlen (e) + 2);
+	      memmove (e, e + 1, strlen (e));
 	    }
 	  else if (*e == '\"')
 	    quoted = ~quoted;
@@ -193,11 +197,11 @@ _mime_munge_content_header (char *field_body)
     }
 }
 
-static char *
+static char    *
 _mime_get_param (char *field_body, const char *param, int *len)
 {
-  char *str, *p, *v, *e;
-  int quoted = 0, was_quoted = 0;
+  char           *str, *p, *v, *e;
+  int             quoted = 0, was_quoted;
 
   if (len == NULL || (str = field_body) == NULL)
     return NULL;
@@ -210,6 +214,7 @@ _mime_get_param (char *field_body, const char *param, int *len)
 	break;
       *len = 0;
       v = e = v + 1;
+      was_quoted = 0;
       while (*e
 	     && (quoted
 		 || (!_ISSPECIAL (*e) && !isspace ((unsigned char) *e))))
@@ -232,7 +237,7 @@ _mime_get_param (char *field_body, const char *param, int *len)
 }
 
 static int
-_mime_setup_buffers (mime_t mime)
+_mime_setup_buffers (mu_mime_t mime)
 {
   if (mime->cur_buf == NULL
       && (mime->cur_buf = malloc (mime->buf_size)) == NULL)
@@ -249,11 +254,12 @@ _mime_setup_buffers (mime_t mime)
 }
 
 static void
-_mime_append_header_line (mime_t mime)
+_mime_append_header_line (mu_mime_t mime)
 {
   if (mime->header_length + mime->line_ndx > mime->header_buf_size)
     {
-      char *nhb;
+      char           *nhb;
+
       if ((nhb =
 	   realloc (mime->header_buf,
 		    mime->header_length + mime->line_ndx + 128)) == NULL)
@@ -267,16 +273,16 @@ _mime_append_header_line (mime_t mime)
 }
 
 static int
-_mime_parse_mpart_message (mime_t mime)
+_mime_parse_mpart_message (mu_mime_t mime)
 {
-  char *cp, *cp2;
-  int blength, mb_length, mb_offset, mb_lines, ret;
-  size_t nbytes;
+  char           *cp, *cp2;
+  int             blength, mb_length, mb_offset, mb_lines, ret;
+  size_t          nbytes;
 
   if (!(mime->flags & MIME_PARSER_ACTIVE))
     {
-      char *boundary;
-      int len;
+      char           *boundary;
+      int             len;
 
       if ((ret = _mime_setup_buffers (mime)) != 0)
 	return ret;
@@ -298,7 +304,7 @@ _mime_parse_mpart_message (mime_t mime)
   blength = strlen (mime->boundary);
 
   while ((ret =
-	  stream_read (mime->stream, mime->cur_buf, mime->buf_size,
+	  mu_stream_read (mime->stream, mime->cur_buf, mime->buf_size,
 		       mime->cur_offset, &nbytes)) == 0 && nbytes)
     {
       cp = mime->cur_buf;
@@ -314,7 +320,7 @@ _mime_parse_mpart_message (mime_t mime)
 		  mime->line_ndx = 0;
 		  mime->parser_state = MIME_STATE_SCAN_BOUNDARY;
 		  break;
-		  
+
 		case MIME_STATE_SCAN_BOUNDARY:
 		  cp2 =
 		    mime->cur_line[0] ==
@@ -325,18 +331,20 @@ _mime_parse_mpart_message (mime_t mime)
 		    {
 		      if ((!strncasecmp (cp2, "--", 2)
 			   && !strncasecmp (cp2 + 2, mime->boundary,
-			    blength))
+					    blength))
 			  || !strncasecmp (cp2, mime->boundary, blength))
 			{
 			  mime->parser_state = MIME_STATE_HEADERS;
 			  mime->flags &= ~MIME_PARSER_HAVE_CR;
 			  mb_length = mime->cur_offset -
-			              mb_offset - mime->line_ndx;
+			    mb_offset - mime->line_ndx;
 			  if (mb_lines > 1)
 			    mb_length++;
-			  if (mime->header_length) /* this skips the preamble */
+			  if (mime->header_length)
+			    /* this skips the preamble */
 			    _mime_append_part (mime, NULL,
-					       mb_offset, mb_length, mb_lines-1);
+					       mb_offset, mb_length,
+					       mb_lines - 1);
 			  if ((&mime->cur_line[mime->line_ndx] - cp2 - 1 >
 			       blength
 			       && !strncasecmp (cp2 + blength + 2, "--", 2))
@@ -353,10 +361,10 @@ _mime_parse_mpart_message (mime_t mime)
 			}
 		    }
 		  mime->line_ndx = 0;
-		  mime->cur_line[0] = *cp; /* stay in this state but
-					      leave '\n' at begining */
+		  mime->cur_line[0] = *cp;	/* stay in this state but
+						   leave '\n' at begining */
 		  break;
-		  
+
 		case MIME_STATE_HEADERS:
 		  mime->line_ndx++;
 		  _mime_append_header_line (mime);
@@ -398,14 +406,25 @@ _mime_parse_mpart_message (mime_t mime)
 /*------ Mime message functions for READING a multipart message -----*/
 
 static int
-_mimepart_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
+_mimepart_body_stream_size (mu_stream_t stream, mu_off_t *psize)
+{
+  size_t s;
+  mu_body_t body = mu_stream_get_owner (stream);
+  int rc =  mu_body_size (body, &s);
+  *psize = s;
+  return rc;
+}
+
+static int
+_mimepart_body_read (mu_stream_t stream,
+		     char *buf, size_t buflen, mu_off_t off,
 		     size_t * nbytes)
 {
-  body_t body = stream_get_owner (stream);
-  message_t msg = body_get_owner (body);
-  struct _mime_part *mime_part = message_get_owner (msg);
-  size_t read_len;
-  int ret = 0;
+  mu_body_t          body = mu_stream_get_owner (stream);
+  mu_message_t       msg = mu_body_get_owner (body);
+  struct _mime_part *mime_part = mu_message_get_owner (msg);
+  size_t          read_len;
+  int             ret = 0;
 
   if (nbytes == NULL)
     return MU_ERR_OUT_NULL;
@@ -414,10 +433,10 @@ _mimepart_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
   read_len = (int) mime_part->len - (int) off;
   if (read_len <= 0)
     {
-      if (!stream_is_seekable (mime_part->mime->stream))
+      if (!mu_stream_is_seekable (mime_part->mime->stream))
 	{
 	  while ((ret =
-		  stream_read (mime_part->mime->stream,
+		  mu_stream_read (mime_part->mime->stream,
 			       buf, buflen,
 			       mime_part->offset + off,
 			       nbytes)) == 0 && *nbytes)
@@ -428,24 +447,26 @@ _mimepart_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
     }
   read_len = (buflen <= read_len) ? buflen : read_len;
 
-  return stream_read (mime_part->mime->stream, buf, read_len,
+  return mu_stream_read (mime_part->mime->stream, buf, read_len,
 		      mime_part->offset + off, nbytes);
 }
 
 static int
-_mimepart_body_transport (stream_t stream, mu_transport_t *tr1, mu_transport_t *tr2)
+_mimepart_body_transport (mu_stream_t stream, mu_transport_t * tr1,
+			  mu_transport_t * tr2)
 {
-  body_t body = stream_get_owner (stream);
-  message_t msg = body_get_owner (body);
-  struct _mime_part *mime_part = message_get_owner (msg);
-  return stream_get_transport2 (mime_part->mime->stream, tr1, tr2);
+  mu_body_t          body = mu_stream_get_owner (stream);
+  mu_message_t       msg = mu_body_get_owner (body);
+  struct _mime_part *mime_part = mu_message_get_owner (msg);
+
+  return mu_stream_get_transport2 (mime_part->mime->stream, tr1, tr2);
 }
 
 static int
-_mimepart_body_size (body_t body, size_t * psize)
+_mimepart_body_size (mu_body_t body, size_t * psize)
 {
-  message_t msg = body_get_owner (body);
-  struct _mime_part *mime_part = message_get_owner (msg);
+  mu_message_t       msg = mu_body_get_owner (body);
+  struct _mime_part *mime_part = mu_message_get_owner (msg);
 
   if (mime_part == NULL)
     return EINVAL;
@@ -455,10 +476,10 @@ _mimepart_body_size (body_t body, size_t * psize)
 }
 
 static int
-_mimepart_body_lines (body_t body, size_t * plines)
+_mimepart_body_lines (mu_body_t body, size_t * plines)
 {
-  message_t msg = body_get_owner (body);
-  struct _mime_part *mime_part = message_get_owner (msg);
+  mu_message_t       msg = mu_body_get_owner (body);
+  struct _mime_part *mime_part = mu_message_get_owner (msg);
 
   if (mime_part == NULL)
     return EINVAL;
@@ -469,23 +490,23 @@ _mimepart_body_lines (body_t body, size_t * plines)
 
 /*------ Mime message/header functions for CREATING multipart message -----*/
 static int
-_mime_set_content_type (mime_t mime)
+_mime_set_content_type (mu_mime_t mime)
 {
-  char content_type[256], *content_te;
-  char boundary[128];
-  header_t hdr = NULL;
-  size_t size;
-  int ret;
+  char            content_type[256], *content_te;
+  char            boundary[128];
+  mu_header_t        hdr = NULL;
+  size_t          size;
+  int             ret;
 
   /* Delayed the creation of the header 'til they create the final message via
-     mime_get_message()  */
+     mu_mime_get_message()  */
   if (mime->hdrs == NULL)
     return 0;
   if (mime->nmtp_parts > 1)
     {
       if (mime->flags & MIME_ADDED_MULTIPART_CT)
 	return 0;
-      if (mime->flags & MIME_MULTIPART_MIXED)
+      if (mime->flags & MU_MIME_MULTIPART_MIXED)
 	strcpy (content_type, "multipart/mixed; boundary=");
       else
 	strcpy (content_type, "multipart/alternative; boundary=");
@@ -501,9 +522,8 @@ _mime_set_content_type (mime_t mime)
       strcat (content_type, "\"");
       mime->flags |= MIME_ADDED_MULTIPART_CT;
 
-      ret =
-	header_set_value (mime->hdrs, MU_HEADER_CONTENT_TYPE,
-			  content_type, 1);
+      ret = mu_header_set_value (mime->hdrs, MU_HEADER_CONTENT_TYPE,
+				 content_type, 1);
     }
   else
     {
@@ -513,31 +533,30 @@ _mime_set_content_type (mime_t mime)
 	return 0;
       mime->flags &= ~MIME_ADDED_MULTIPART_CT;
       if (mime->nmtp_parts)
-	message_get_header (mime->mtp_parts[0]->msg, &hdr);
+	mu_message_get_header (mime->mtp_parts[0]->msg, &hdr);
       if (hdr == NULL
-	  || header_get_value (hdr, MU_HEADER_CONTENT_TYPE,
-			       NULL, 0, &size) != 0 || size == 0)
+	  || mu_header_get_value (hdr, MU_HEADER_CONTENT_TYPE,
+				  NULL, 0, &size) != 0 || size == 0)
 	strcpy (content_type, "text/plain; charset=us-ascii");
       else
-	header_get_value (hdr, MU_HEADER_CONTENT_TYPE,
-			  content_type, sizeof (content_type), &size);
+	mu_header_get_value (hdr, MU_HEADER_CONTENT_TYPE,
+			     content_type, sizeof (content_type), &size);
 
-      ret =
-	header_set_value (mime->hdrs, MU_HEADER_CONTENT_TYPE,
-			  content_type, 1);
+      ret = mu_header_set_value (mime->hdrs, MU_HEADER_CONTENT_TYPE,
+				 content_type, 1);
       if (ret)
 	return ret;
 
       /* if the only part contains a transfer-encoding
          field, set it on the message header too */
       if (hdr &&
-	  header_aget_value (hdr,
-			     MU_HEADER_CONTENT_TRANSFER_ENCODING,
-			     &content_te) == 0)
+	  mu_header_aget_value (hdr,
+				MU_HEADER_CONTENT_TRANSFER_ENCODING,
+				&content_te) == 0)
 	{
-	  ret = header_set_value (mime->hdrs,
-				  MU_HEADER_CONTENT_TRANSFER_ENCODING,
-				  content_te, 1);
+	  ret = mu_header_set_value (mime->hdrs,
+				     MU_HEADER_CONTENT_TRANSFER_ENCODING,
+				     content_te, 1);
 	  free (content_te);
 	}
     }
@@ -545,18 +564,23 @@ _mime_set_content_type (mime_t mime)
   return ret;
 }
 
-#define ADD_CHAR(buf, c, offset, buflen, nbytes) {*(buf)++ = c; (offset)++; (nbytes)++;if (--(buflen) == 0) return 0;}
+#define ADD_CHAR(buf, c, offset, buflen, nbytes) do {\
+ *(buf)++ = c;\
+ (offset)++;\
+ (nbytes)++;\
+ if (--(buflen) == 0) return 0;\
+} while (0)
 
 static int
-_mime_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
+_mime_body_read (mu_stream_t stream, char *buf, size_t buflen, mu_off_t off,
 		 size_t * nbytes)
 {
-  body_t body = stream_get_owner (stream);
-  message_t msg = body_get_owner (body);
-  mime_t mime = message_get_owner (msg);
-  int ret = 0;
-  size_t part_nbytes = 0;
-  stream_t msg_stream = NULL;
+  mu_body_t          body = mu_stream_get_owner (stream);
+  mu_message_t       msg = mu_body_get_owner (body);
+  mu_mime_t          mime = mu_message_get_owner (msg);
+  int             ret = 0;
+  size_t          part_nbytes = 0;
+  mu_stream_t        msg_stream = NULL;
 
   if (mime->nmtp_parts == 0)
     return EINVAL;
@@ -583,7 +607,8 @@ _mime_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
 	{
 	  if (mime->nmtp_parts > 1)
 	    {
-	      int len;
+	      int             len;
+
 	      if (mime->flags & MIME_INSERT_BOUNDARY)
 		{
 		  if ((mime->flags & MIME_ADDING_BOUNDARY) == 0)
@@ -620,21 +645,21 @@ _mime_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
 		}
 	      if (mime->cur_part >= mime->nmtp_parts)
 		return 0;
-	      message_get_stream (mime->mtp_parts[mime->cur_part]->msg,
+	      mu_message_get_stream (mime->mtp_parts[mime->cur_part]->msg,
 				  &msg_stream);
 	    }
 	  else
 	    {
-	      body_t part_body;
+	      mu_body_t          part_body;
 
 	      if (mime->cur_part >= mime->nmtp_parts)
 		return 0;
-	      message_get_body (mime->mtp_parts[mime->cur_part]->msg,
+	      mu_message_get_body (mime->mtp_parts[mime->cur_part]->msg,
 				&part_body);
-	      body_get_stream (part_body, &msg_stream);
+	      mu_body_get_stream (part_body, &msg_stream);
 	    }
 	  ret =
-	    stream_read (msg_stream, buf, buflen,
+	    mu_stream_read (msg_stream, buf, buflen,
 			 mime->part_offset, &part_nbytes);
 	  if (part_nbytes)
 	    {
@@ -657,26 +682,27 @@ _mime_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
 }
 
 static int
-_mime_body_transport (stream_t stream, mu_transport_t *tr1, mu_transport_t *tr2)
+_mime_body_transport (mu_stream_t stream, mu_transport_t * tr1,
+		      mu_transport_t * tr2)
 {
-  body_t body = stream_get_owner (stream);
-  message_t msg = body_get_owner (body);
-  mime_t mime = message_get_owner (msg);
-  stream_t msg_stream = NULL;
+  mu_body_t          body = mu_stream_get_owner (stream);
+  mu_message_t       msg = mu_body_get_owner (body);
+  mu_mime_t          mime = mu_message_get_owner (msg);
+  mu_stream_t        msg_stream = NULL;
 
   if (mime->nmtp_parts == 0 || mime->cur_offset == 0)
     return EINVAL;
-  message_get_stream (mime->mtp_parts[mime->cur_part]->msg, &msg_stream);
-  return stream_get_transport2 (msg_stream, tr1, tr2);
+  mu_message_get_stream (mime->mtp_parts[mime->cur_part]->msg, &msg_stream);
+  return mu_stream_get_transport2 (msg_stream, tr1, tr2);
 }
 
 static int
-_mime_body_size (body_t body, size_t * psize)
+_mime_body_size (mu_body_t body, size_t * psize)
 {
-  message_t msg = body_get_owner (body);
-  mime_t mime = message_get_owner (msg);
-  int i, ret;
-  size_t size;
+  mu_message_t       msg = mu_body_get_owner (body);
+  mu_mime_t          mime = mu_message_get_owner (msg);
+  int             i, ret;
+  size_t          size;
 
   if (mime->nmtp_parts == 0)
     return EINVAL;
@@ -685,7 +711,7 @@ _mime_body_size (body_t body, size_t * psize)
     return ret;
   for (i = 0; i < mime->nmtp_parts; i++)
     {
-      message_size (mime->mtp_parts[i]->msg, &size);
+      mu_message_size (mime->mtp_parts[i]->msg, &size);
       *psize += size;
       if (mime->nmtp_parts > 1)	/* boundary line */
 	*psize += strlen (mime->boundary) + 3;
@@ -697,12 +723,12 @@ _mime_body_size (body_t body, size_t * psize)
 }
 
 static int
-_mime_body_lines (body_t body, size_t * plines)
+_mime_body_lines (mu_body_t body, size_t * plines)
 {
-  message_t msg = body_get_owner (body);
-  mime_t mime = message_get_owner (msg);
-  int i, ret;
-  size_t lines;
+  mu_message_t       msg = mu_body_get_owner (body);
+  mu_mime_t          mime = mu_message_get_owner (msg);
+  int             i, ret;
+  size_t          lines;
 
   if (mime->nmtp_parts == 0)
     return EINVAL;
@@ -711,7 +737,7 @@ _mime_body_lines (body_t body, size_t * plines)
     return ret;
   for (i = 0; i < mime->nmtp_parts; i++)
     {
-      message_lines (mime->mtp_parts[i]->msg, &lines);
+      mu_message_lines (mime->mtp_parts[i]->msg, &lines);
       plines += lines;
       if (mime->nmtp_parts > 1)	/* boundary line */
 	plines++;
@@ -720,12 +746,12 @@ _mime_body_lines (body_t body, size_t * plines)
 }
 
 int
-mime_create (mime_t * pmime, message_t msg, int flags)
+mu_mime_create (mu_mime_t * pmime, mu_message_t msg, int flags)
 {
-  mime_t mime = NULL;
-  int ret = 0;
-  size_t size;
-  body_t body;
+  mu_mime_t          mime = NULL;
+  int             ret = 0;
+  size_t          size;
+  mu_body_t          body;
 
   if (pmime == NULL)
     return EINVAL;
@@ -734,20 +760,19 @@ mime_create (mime_t * pmime, message_t msg, int flags)
     return ENOMEM;
   if (msg)
     {
-      if ((ret = message_get_header (msg, &mime->hdrs)) == 0)
+      if ((ret = mu_message_get_header (msg, &mime->hdrs)) == 0)
 	{
 	  if ((ret =
-	       header_get_value (mime->hdrs,
-				 MU_HEADER_CONTENT_TYPE,
-				 NULL, 0, &size)) == 0 && size)
+	       mu_header_get_value (mime->hdrs,
+				    MU_HEADER_CONTENT_TYPE,
+				    NULL, 0, &size)) == 0 && size)
 	    {
 	      if ((mime->content_type = malloc (size + 1)) == NULL)
 		ret = ENOMEM;
-	      else if ((ret =
-			header_get_value (mime->hdrs,
-					  MU_HEADER_CONTENT_TYPE,
-					  mime->content_type,
-					  size + 1, 0)) == 0)
+	      else if ((ret = mu_header_get_value (mime->hdrs,
+						   MU_HEADER_CONTENT_TYPE,
+						   mime->content_type,
+						   size + 1, 0)) == 0)
 		_mime_munge_content_header (mime->content_type);
 	    }
 	  else
@@ -765,14 +790,14 @@ mime_create (mime_t * pmime, message_t msg, int flags)
 	    {
 	      mime->msg = msg;
 	      mime->buf_size = MIME_DFLT_BUF_SIZE;
-	      message_get_body (msg, &body);
-	      body_get_stream (body, &(mime->stream));
+	      mu_message_get_body (msg, &body);
+	      mu_body_get_stream (body, &(mime->stream));
 	    }
 	}
     }
   else
     {
-      mime->flags |= MIME_NEW_MESSAGE | MIME_MULTIPART_MIXED;
+      mime->flags |= MIME_NEW_MESSAGE | MU_MIME_MULTIPART_MIXED;
     }
   if (ret != 0)
     {
@@ -789,11 +814,11 @@ mime_create (mime_t * pmime, message_t msg, int flags)
 }
 
 void
-mime_destroy (mime_t * pmime)
+mu_mime_destroy (mu_mime_t * pmime)
 {
-  mime_t mime;
+  mu_mime_t          mime;
   struct _mime_part *mime_part;
-  int i;
+  int             i;
 
   if (pmime && *pmime)
     {
@@ -804,15 +829,15 @@ mime_destroy (mime_t * pmime)
 	    {
 	      mime_part = mime->mtp_parts[i];
 	      if (mime_part->msg && mime->flags & MIME_NEW_MESSAGE)
-		message_unref (mime_part->msg);
+		mu_message_unref (mime_part->msg);
 	      else
-		message_destroy (&mime_part->msg, mime_part);
+		mu_message_destroy (&mime_part->msg, mime_part);
 	      free (mime_part);
 	    }
 	  free (mime->mtp_parts);
 	}
       if (mime->msg && mime->flags & MIME_NEW_MESSAGE)
-	message_destroy (&mime->msg, mime);
+	mu_message_destroy (&mime->msg, mime);
       if (mime->content_type)
 	free (mime->content_type);
       if (mime->cur_buf)
@@ -829,15 +854,15 @@ mime_destroy (mime_t * pmime)
 }
 
 int
-mime_get_part (mime_t mime, size_t part, message_t * msg)
+mu_mime_get_part (mu_mime_t mime, size_t part, mu_message_t * msg)
 {
-  size_t nmtp_parts;
-  int ret = 0, flags = 0;
-  stream_t stream;
-  body_t body;
+  size_t          nmtp_parts;
+  int             ret = 0, flags = 0;
+  mu_stream_t        stream;
+  mu_body_t          body;
   struct _mime_part *mime_part;
 
-  if ((ret = mime_get_num_parts (mime, &nmtp_parts)) == 0)
+  if ((ret = mu_mime_get_num_parts (mime, &nmtp_parts)) == 0)
     {
       if (part < 1 || part > nmtp_parts)
 	return EINVAL;
@@ -847,22 +872,26 @@ mime_get_part (mime_t mime, size_t part, message_t * msg)
 	{
 	  mime_part = mime->mtp_parts[part - 1];
 	  if (!mime_part->body_created
-	      && (ret = body_create (&body, mime_part->msg)) == 0)
+	      && (ret = mu_body_create (&body, mime_part->msg)) == 0)
 	    {
-	      body_set_size (body, _mimepart_body_size, mime_part->msg);
-	      body_set_lines (body, _mimepart_body_lines, mime_part->msg);
-	      stream_get_flags (mime->stream, &flags);
+	      mu_body_set_size (body, _mimepart_body_size, mime_part->msg);
+	      mu_body_set_lines (body, _mimepart_body_lines, mime_part->msg);
+	      mu_stream_get_flags (mime->stream, &flags);
 	      if ((ret =
-		   stream_create (&stream,
+		   mu_stream_create (&stream,
 				  MU_STREAM_READ | (flags &
 						    (MU_STREAM_SEEKABLE
 						     | MU_STREAM_NONBLOCK)),
 				  body)) == 0)
 		{
-		  stream_set_read (stream, _mimepart_body_read, body);
-		  stream_set_get_transport2 (stream, _mimepart_body_transport, body);
-		  body_set_stream (body, stream, mime_part->msg);
-		  message_set_body (mime_part->msg, body, mime_part);
+		  mu_stream_set_read (stream, _mimepart_body_read, body);
+		  mu_stream_set_get_transport2 (stream,
+						_mimepart_body_transport,
+						body);
+		  mu_stream_set_size (stream, _mimepart_body_stream_size,
+				      body);
+		  mu_body_set_stream (body, stream, mime_part->msg);
+		  mu_message_set_body (mime_part->msg, body, mime_part);
 		  mime_part->body_created = 1;
 		}
 	    }
@@ -873,13 +902,13 @@ mime_get_part (mime_t mime, size_t part, message_t * msg)
 }
 
 int
-mime_get_num_parts (mime_t mime, size_t * nmtp_parts)
+mu_mime_get_num_parts (mu_mime_t mime, size_t * nmtp_parts)
 {
-  int ret = 0;
+  int             ret = 0;
 
   if (mime->nmtp_parts == 0 || mime->flags & MIME_PARSER_ACTIVE)
     {
-      if (mime_is_multipart (mime))
+      if (mu_mime_is_multipart (mime))
 	{
 	  if ((ret = _mime_parse_mpart_message (mime)) != 0)
 	    return (ret);
@@ -893,9 +922,9 @@ mime_get_num_parts (mime_t mime, size_t * nmtp_parts)
 }
 
 int
-mime_add_part (mime_t mime, message_t msg)
+mu_mime_add_part (mu_mime_t mime, mu_message_t msg)
 {
-  int ret;
+  int             ret;
 
   if (mime == NULL || msg == NULL || (mime->flags & MIME_NEW_MESSAGE) == 0)
     return EINVAL;
@@ -905,11 +934,11 @@ mime_add_part (mime_t mime, message_t msg)
 }
 
 int
-mime_get_message (mime_t mime, message_t * msg)
+mu_mime_get_message (mu_mime_t mime, mu_message_t * msg)
 {
-  stream_t body_stream;
-  body_t body;
-  int ret = 0;
+  mu_stream_t        body_stream;
+  mu_body_t          body;
+  int             ret = 0;
 
   if (mime == NULL || msg == NULL)
     return EINVAL;
@@ -917,33 +946,37 @@ mime_get_message (mime_t mime, message_t * msg)
     {
       if ((mime->flags & MIME_NEW_MESSAGE) == 0)
 	return EINVAL;
-      if ((ret = message_create (&mime->msg, mime)) == 0)
+      if ((ret = mu_message_create (&mime->msg, mime)) == 0)
 	{
-	  if ((ret = header_create (&mime->hdrs, NULL, 0, mime->msg)) == 0)
+	  if ((ret = mu_header_create (&mime->hdrs, NULL, 0, mime->msg)) == 0)
 	    {
-	      message_set_header (mime->msg, mime->hdrs, mime);
-	      header_set_value (mime->hdrs, MU_HEADER_MIME_VERSION, "1.0", 0);
+	      mu_message_set_header (mime->msg, mime->hdrs, mime);
+	      mu_header_set_value (mime->hdrs, MU_HEADER_MIME_VERSION, "1.0",
+				   0);
 	      if ((ret = _mime_set_content_type (mime)) == 0)
 		{
-		  if ((ret = body_create (&body, mime->msg)) == 0)
+		  if ((ret = mu_body_create (&body, mime->msg)) == 0)
 		    {
-		      message_set_body (mime->msg, body, mime);
-		      body_set_size (body, _mime_body_size, mime->msg);
-		      body_set_lines (body, _mime_body_lines, mime->msg);
+		      mu_message_set_body (mime->msg, body, mime);
+		      mu_body_set_size (body, _mime_body_size, mime->msg);
+		      mu_body_set_lines (body, _mime_body_lines, mime->msg);
 		      if ((ret =
-			   stream_create (&body_stream, MU_STREAM_READ, body))
+			   mu_stream_create (&body_stream, MU_STREAM_READ, body))
 			  == 0)
 			{
-			  stream_set_read (body_stream, _mime_body_read, body);
-			  stream_set_get_transport2 (body_stream, _mime_body_transport, body);
-			  body_set_stream (body, body_stream, mime->msg);
+			  mu_stream_set_read (body_stream, _mime_body_read,
+					   body);
+			  mu_stream_set_get_transport2 (body_stream,
+						     _mime_body_transport,
+						     body);
+			  mu_body_set_stream (body, body_stream, mime->msg);
 			  *msg = mime->msg;
 			  return 0;
 			}
 		    }
 		}
 	    }
-	  message_destroy (&mime->msg, mime);
+	  mu_message_destroy (&mime->msg, mime);
 	  mime->msg = NULL;
 	}
     }
@@ -953,7 +986,7 @@ mime_get_message (mime_t mime, message_t * msg)
 }
 
 int
-mime_is_multipart (mime_t mime)
+mu_mime_is_multipart (mu_mime_t mime)
 {
   if (mime->content_type)
     return (strncasecmp ("multipart", mime->content_type,
