@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +12,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -52,6 +54,7 @@
 #define ARG_LOCK_EXTERNAL_PROGRAM 6
 #define ARG_SHOW_OPTIONS          7
 #define ARG_LICENSE               8
+#define ARG_MAILBOX_TYPE          9
 
 static struct argp_option mu_common_argp_options[] = 
 {
@@ -71,6 +74,8 @@ static struct argp_option mu_license_argp_option[] = {
 static struct argp_option mu_mailbox_argp_option[] = {
   {"mail-spool", 'm', N_("URL"), 0,
    N_("Use specified URL as a mailspool directory"), 0},
+  {"mailbox-type", ARG_MAILBOX_TYPE, N_("PROTO"), 0,
+   N_("Default mailbox type to use"), 0 },
   {"lock-flags", ARG_LOCK_FLAGS, N_("FLAGS"), 0,
    N_("Default locker flags (E=external, R=retry, T=time, P=pid)"), 0},
   {"lock-retry-timeout", ARG_LOCK_RETRY_TIMEOUT, N_("SECONDS"), 0,
@@ -80,7 +85,7 @@ static struct argp_option mu_mailbox_argp_option[] = {
   {"lock-expire-timeout", ARG_LOCK_EXPIRE_TIMEOUT, N_("SECONDS"), 0,
    N_("Number of seconds after which the lock expires"), },
   {"external-locker", ARG_LOCK_EXTERNAL_PROGRAM, N_("PATH"), 0,
-   N_("Set full path to the external locker program.") },
+   N_("Set full path to the external locker program") },
   { NULL,      0, NULL, 0, NULL, 0 }
 };
 
@@ -119,16 +124,16 @@ static struct argp_option mu_daemon_argp_option[] = {
   {"timeout", 't', N_("NUMBER"), 0,
    N_("Set idle timeout value to NUMBER seconds"), 0},
   {"transcript", 'x', NULL, 0,
-   N_("output session transcript via syslog"), 0},
+   N_("Output session transcript via syslog"), 0},
   {"pidfile", 'P', N_("FILE"), 0,
    N_("Set PID file"), 0},
   { NULL,      0, NULL, 0, NULL, 0 }
 };
 
-static error_t mu_common_argp_parser __P((int key, char *arg,
-					  struct argp_state *state));
-static error_t mu_daemon_argp_parser __P((int key, char *arg,
-					  struct argp_state *state));
+static error_t mu_common_argp_parser (int key, char *arg,
+				      struct argp_state *state);
+static error_t mu_daemon_argp_parser (int key, char *arg,
+				      struct argp_state *state);
 
 struct argp mu_common_argp = {
   mu_common_argp_options,
@@ -245,7 +250,7 @@ parse_log_facility (const char *str)
   for (i = 0; i < sizeof (syslog_kw) / sizeof (syslog_kw[0]); i++)
     if (strcasecmp (syslog_kw[i].name, str) == 0)
       return syslog_kw[i].facility;
-  fprintf (stderr, _("unknown facility `%s'\n"), str);
+  fprintf (stderr, _("Unknown facility `%s'\n"), str);
   return LOG_FACILITY;
 }
 
@@ -260,9 +265,12 @@ char *mu_license_text =
     "   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
     "   GNU General Public License for more details.\n"
     "\n"
-    "   You should have received a copy of the GNU General Public License\n"
-    "   along with GNU Mailutils; if not, write to the Free Software\n"
-    "   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA\n\n");
+    "   You should have received a copy of the GNU General Public License along\n"
+    "   with GNU Mailutils; if not, write to the Free Software Foundation,\n"
+    "   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA\n"
+    "\n"
+    "\n"
+);
 
 static char *mu_conf_option[] = {
   "VERSION=" VERSION,
@@ -329,6 +337,12 @@ static char *mu_conf_option[] = {
 #ifdef ENABLE_SENDMAIL
   "ENABLE_SENDMAIL",
 #endif
+#ifdef ENABLE_NNTP
+  "ENABLE_NNTP",
+#endif
+#ifdef ENABLE_RADIUS
+  "ENABLE_RADIUS",
+#endif
 #ifdef WITH_INCLUDED_LIBINTL
   "WITH_INCLUDED_LIBINTL",
 #endif
@@ -371,7 +385,6 @@ static error_t
 mu_common_argp_parser (int key, char *arg, struct argp_state *state)
 {
   int err = 0;
-  char *p;
 
   switch (key)
     {
@@ -387,9 +400,17 @@ mu_common_argp_parser (int key, char *arg, struct argp_state *state)
       
       /* mailbox */
     case 'm':
-      mu_path_maildir = arg;
+      err = mu_set_mail_directory (arg);
+      if (err)
+	argp_error (state, _("Cannot set mail directory name: %s"),
+		    mu_strerror (err));
       break;
 
+    case ARG_MAILBOX_TYPE:
+      if (mu_mailbox_set_default_proto (arg))
+	argp_error (state, _("Invalid mailbox type: %s"), arg);
+      break;
+      
     case ARG_LOCK_FLAGS:
       {
 	int flags = 0;
@@ -414,64 +435,64 @@ mu_common_argp_parser (int key, char *arg, struct argp_state *state)
 		break;
 		
 	      default:
-		argp_error (state, _("invalid lock flag '%c'"), *arg);
+		argp_error (state, _("Invalid lock flag `%c'"), *arg);
 	      }
 	  }
-	locker_set_default_flags (flags, mu_locker_set_flags);
+	mu_locker_set_default_flags (flags, mu_locker_assign);
       }
       break;
 
     case ARG_LOCK_RETRY_COUNT:
       {
 	size_t t = strtoul (arg, NULL, 0);
-	locker_set_default_retry_count (t);
-	locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
+	mu_locker_set_default_retry_count (t);
+	mu_locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
       }
       break;
 	  
     case ARG_LOCK_RETRY_TIMEOUT:
       {
 	time_t t = strtoul (arg, NULL, 0);
-	locker_set_default_retry_timeout (t);
-	locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
+	mu_locker_set_default_retry_timeout (t);
+	mu_locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
       }
       break;
 
     case ARG_LOCK_EXPIRE_TIMEOUT:
       {
 	time_t t = strtoul (arg, NULL, 0);
-	locker_set_default_expire_timeout (t);
-	locker_set_default_flags (MU_LOCKER_EXTERNAL, mu_locker_set_bit);
+	mu_locker_set_default_expire_timeout (t);
+	mu_locker_set_default_flags (MU_LOCKER_EXTERNAL, mu_locker_set_bit);
       }
       break;
 
     case ARG_LOCK_EXTERNAL_PROGRAM:
-      locker_set_default_external_program (arg);
-      locker_set_default_flags (MU_LOCKER_TIME, mu_locker_set_bit);
+      mu_locker_set_default_external_program (arg);
+      mu_locker_set_default_flags (MU_LOCKER_TIME, mu_locker_set_bit);
       break;
       
       /* address */
     case 'E':
       if ((err = mu_set_user_email(arg)) != 0)
 	  {
-	    argp_error (state, _("invalid email-addr '%s': %s"),
-		arg, mu_strerror(err));
+	    argp_error (state, _("Invalid email address `%s': %s"),
+			arg, mu_strerror(err));
 	  }
       break;
 
     case 'D':
       if ((err = mu_set_user_email_domain(arg)) != 0)
 	  {
-	    argp_error (state, _("invalid email-domain '%s': %s"),
+	    argp_error (state, _("Invalid email domain `%s': %s"),
 		arg, mu_strerror(err));
 	  }
       break;
 
       /* mailer */
     case 'M':
-      if ((err = mailer_set_url_default (arg)) != 0)
+      if ((err = mu_mailer_set_url_default (arg)) != 0)
 	  {
-	    argp_error (state, _("invalid mailer url '%s': %s"),
+	    argp_error (state, _("Invalid mailer URL `%s': %s"),
 			arg, mu_strerror(err));
 	  }
       break;
@@ -482,12 +503,6 @@ mu_common_argp_parser (int key, char *arg, struct argp_state *state)
       break;
 
     case ARGP_KEY_FINI:
-      p = mu_normalize_maildir (mu_path_maildir);
-      if (!p)
-	{
-	  argp_error (state, _("badly formed mailspool path: %s"), mu_path_maildir);
-	}
-      mu_path_maildir = p;
       break;
 
     default:
@@ -648,9 +663,9 @@ read_rc (const char *progname, const char *name, const char *capa[],
 	  int i, n_argc = 0;
 	  char **n_argv;
               
-	  if (argcv_get (p, "", NULL, &n_argc, &n_argv))
+	  if (mu_argcv_get (p, "", NULL, &n_argc, &n_argv))
 	    {
-	      argcv_free (n_argc, n_argv);
+	      mu_argcv_free (n_argc, n_argv);
 	      if (linebuf)
 		free (linebuf);
 	      linebuf = NULL;
@@ -665,7 +680,7 @@ read_rc (const char *progname, const char *name, const char *capa[],
 	    }
 	  
 	  for (i = 0; i < n_argc; i++)
-	    x_argv[x_argc++] = n_argv[i];
+	    x_argv[x_argc++] = mu_tilde_expansion (n_argv[i], "/", NULL);
 	  
 	  free (n_argv);
 	}
@@ -858,7 +873,7 @@ mu_build_argp (const struct argp *template, const char *capa[])
   ap = calloc (n + 1, sizeof (*ap));
   if (!ap)
     {
-      mu_error (_("out of memory"));
+      mu_error (_("Out of memory"));
       abort ();
     }
 
@@ -896,7 +911,7 @@ mu_build_argp (const struct argp *template, const char *capa[])
   argp = malloc (sizeof (*argp));
   if (!argp)
     {
-      mu_error (_("out of memory"));
+      mu_error (_("Out of memory"));
       abort ();
     }
 
