@@ -1172,13 +1172,44 @@ int
 mu_string_unfold (char *text, size_t *plen)
 {
   char *p, *q;
-
+  enum uf_state { uf_init, uf_nl, uf_fold } state = uf_init;
+#define ISSPACE(c) (c == '\r' || c == ' ' || c == '\t')
+  
   if (!text)
     return EINVAL;
   
   for (p = q = text; *q; q++)
-    if (*q != '\n')
-      *p++ = *q;
+    {
+      switch (state)
+	{
+	case uf_init:
+	  if (*q == '\n')
+	    state = uf_nl;
+	  else
+	    *p++ = *q;
+	  break;
+
+	case uf_nl:
+	  if (ISSPACE (*q))
+	    state = uf_fold;
+	  else
+	    {
+	      state = uf_init;
+	      *p++ = *q;
+	    }
+	  break;
+
+	case uf_fold:
+	  if (!ISSPACE (*q))
+	    {
+	      *p++ = ' ';
+	      *p++ = *q;
+	      state = uf_init;
+	    }
+	  break;
+	}
+    }
+  
   *p++ = 0;
   if (plen)
     *plen = p - text;
@@ -1228,7 +1259,9 @@ mu_scheme_autodetect_p (const char *scheme,  const char **path)
       *path += MU_FILE_SCHEME_LEN;
       return 1;
     }
-  if (strncmp (MU_PATH_SCHEME, scheme, MU_PATH_SCHEME_LEN) == 0)
+  if (access (scheme, F_OK) == 0
+      /* FIXME: this can return true even if the folder is unreadable */
+      || strncmp (MU_PATH_SCHEME, scheme, MU_PATH_SCHEME_LEN) == 0)
     return 1;
   return 0;
 }
