@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003, 2004, 
+   2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +12,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -43,14 +45,14 @@ struct myticket_data
   char *filename;
 };
 
-static int   myticket_create  __P ((ticket_t *, const char *, const char *, const char *));
-static void  myticket_destroy __P ((ticket_t));
-static int   myticket_pop     __P ((ticket_t, url_t, const char *, char **));
-static int   get_pass         __P ((url_t, const char *, const char *, char**));
-static int   get_user         __P ((url_t, const char *, char **));
+static int   myticket_create  (mu_ticket_t *, const char *, const char *, const char *);
+static void  myticket_destroy (mu_ticket_t);
+static int   myticket_pop     (mu_ticket_t, mu_url_t, const char *, char **);
+static int   get_pass         (mu_url_t, const char *, const char *, char**);
+static int   get_user         (mu_url_t, const char *, char **);
 
 int
-wicket_create (wicket_t *pwicket, const char *filename)
+mu_wicket_create (mu_wicket_t *pwicket, const char *filename)
 {
   struct stat st;
 
@@ -75,11 +77,11 @@ wicket_create (wicket_t *pwicket, const char *filename)
 }
 
 void
-wicket_destroy (wicket_t *pwicket)
+mu_wicket_destroy (mu_wicket_t *pwicket)
 {
   if (pwicket && *pwicket)
     {
-      wicket_t wicket = *pwicket;
+      mu_wicket_t wicket = *pwicket;
       if (wicket->filename)
 	free (wicket->filename);
       free (wicket);
@@ -88,7 +90,7 @@ wicket_destroy (wicket_t *pwicket)
 }
 
 int
-wicket_get_filename (wicket_t wicket, char *filename, size_t len,
+mu_wicket_get_filename (mu_wicket_t wicket, char *filename, size_t len,
 		     size_t *pwriten)
 {
  size_t n;
@@ -101,7 +103,7 @@ wicket_get_filename (wicket_t wicket, char *filename, size_t len,
 }
 
 int
-wicket_set_filename (wicket_t wicket, const char *filename)
+mu_wicket_set_filename (mu_wicket_t wicket, const char *filename)
 {
   if (wicket == NULL)
     return EINVAL;
@@ -114,8 +116,8 @@ wicket_set_filename (wicket_t wicket, const char *filename)
 }
 
 int
-wicket_set_ticket (wicket_t wicket, int get_ticket
-		   __P ((wicket_t, const char *, const char *, ticket_t *)))
+mu_wicket_set_ticket (mu_wicket_t wicket, int (*get_ticket)
+		      (mu_wicket_t, const char *, const char *, mu_ticket_t *))
 {
   if (wicket == NULL)
     return EINVAL;
@@ -125,7 +127,7 @@ wicket_set_ticket (wicket_t wicket, int get_ticket
 }
 
 int
-wicket_get_ticket (wicket_t wicket, ticket_t *pticket, const char *user,
+mu_wicket_get_ticket (mu_wicket_t wicket, mu_ticket_t *pticket, const char *user,
 		   const char *type)
 {
   if (wicket == NULL || pticket == NULL)
@@ -140,30 +142,30 @@ wicket_get_ticket (wicket_t wicket, ticket_t *pticket, const char *user,
 }
 
 static int
-myticket_create (ticket_t *pticket, const char *user, const char *pass, const char *filename)
+myticket_create (mu_ticket_t *pticket, const char *user, const char *pass, const char *filename)
 {
   struct myticket_data *mdata;
-  int status = ticket_create (pticket, NULL);
+  int status = mu_ticket_create (pticket, NULL);
   if (status != 0)
     return status;
 
   mdata = calloc (1, sizeof *mdata);
   if (mdata == NULL)
     {
-      ticket_destroy (pticket, NULL);
+      mu_ticket_destroy (pticket, NULL);
       return ENOMEM;
     }
 
-  ticket_set_destroy (*pticket, myticket_destroy, NULL);
-  ticket_set_pop (*pticket, myticket_pop, NULL);
-  ticket_set_data (*pticket, mdata, NULL);
+  mu_ticket_set_destroy (*pticket, myticket_destroy, NULL);
+  mu_ticket_set_pop (*pticket, myticket_pop, NULL);
+  mu_ticket_set_data (*pticket, mdata, NULL);
 
   if (filename)
     {
       mdata->filename = strdup (filename);
       if (mdata->filename == NULL)
 	{
-	  ticket_destroy (pticket, NULL);
+	  mu_ticket_destroy (pticket, NULL);
 	  status = ENOMEM;
 	  return status;
 	}
@@ -174,7 +176,7 @@ myticket_create (ticket_t *pticket, const char *user, const char *pass, const ch
       mdata->user = strdup (user);
       if (mdata->user == NULL)
 	{
-	  ticket_destroy (pticket, NULL);
+	  mu_ticket_destroy (pticket, NULL);
 	  status = ENOMEM;
 	  return status;
 	}
@@ -185,7 +187,7 @@ myticket_create (ticket_t *pticket, const char *user, const char *pass, const ch
       mdata->pass = strdup (pass);
       if (mdata->pass == NULL)
 	{
-	  ticket_destroy (pticket, NULL);
+	  mu_ticket_destroy (pticket, NULL);
 	  status = ENOMEM;
 	  return status;
 	}
@@ -195,12 +197,12 @@ myticket_create (ticket_t *pticket, const char *user, const char *pass, const ch
 }
 
 static int
-myticket_pop (ticket_t ticket, url_t url, const char *challenge, char **parg)
+myticket_pop (mu_ticket_t ticket, mu_url_t url, const char *challenge, char **parg)
 {
   struct myticket_data *mdata = NULL;
   int e = 0;
 
-  ticket_get_data (ticket, (void **)&mdata);
+  mu_ticket_get_data (ticket, (void **)&mdata);
   if (challenge &&
     (
       strstr (challenge, "ass") != NULL ||
@@ -236,10 +238,10 @@ myticket_pop (ticket_t ticket, url_t url, const char *challenge, char **parg)
 }
 
 static void
-myticket_destroy (ticket_t ticket)
+myticket_destroy (mu_ticket_t ticket)
 {
   struct myticket_data *mdata = NULL;
-  ticket_get_data (ticket, (void **)&mdata);
+  mu_ticket_get_data (ticket, (void **)&mdata);
   if (mdata)
     {
       if (mdata->user)
@@ -253,7 +255,7 @@ myticket_destroy (ticket_t ticket)
 }
 
 static int
-get_ticket (url_t url, const char *user, const char *filename, url_t * ticket)
+get_ticket (mu_url_t url, const char *user, const char *filename, mu_url_t * ticket)
 {
   int err = 0;
   FILE *fp = NULL;
@@ -280,7 +282,7 @@ get_ticket (url_t url, const char *user, const char *filename, url_t * ticket)
     {
       char *ptr = buf;
       int len = 0;
-      url_t u = NULL;
+      mu_url_t u = NULL;
 
       /* fgets:
 	 1) return true, read some data
@@ -327,26 +329,26 @@ get_ticket (url_t url, const char *user, const char *filename, url_t * ticket)
       if ((len = strlen (ptr)) == 0)
 	continue;
 
-      if ((err = url_create (&u, ptr)) != 0)
+      if ((err = mu_url_create (&u, ptr)) != 0)
 	{
 	  free (buf);
 	  fclose (fp);
 	  return err;
 	}
-      if ((err = url_parse (u)) != 0)
+      if ((err = mu_url_parse (u)) != 0)
 	{
 	  /* TODO: send output to the debug stream */
 	  /*
-	     printf ("url_parse %s failed: [%d] %s\n", str, err, mu_strerror (err));
+	     printf ("mu_url_parse %s failed: [%d] %s\n", str, err, mu_strerror (err));
 	   */
-	  url_destroy (&u);
+	  mu_url_destroy (&u);
 	  continue;
 	}
 
 
-      if (!url_is_ticket (u, url))
+      if (!mu_url_is_ticket (u, url))
 	{
-	  url_destroy (&u);
+	  mu_url_destroy (&u);
 	  continue;
 	}
       /* Also needs to be for name, if we required. */
@@ -355,7 +357,7 @@ get_ticket (url_t url, const char *user, const char *filename, url_t * ticket)
 	  if (u->name && strcmp (u->name, "*") != 0
 	      && strcmp (user, u->name) != 0)
 	    {
-	      url_destroy (&u);
+	      mu_url_destroy (&u);
 	      continue;
 	    }
 	}
@@ -373,24 +375,24 @@ get_ticket (url_t url, const char *user, const char *filename, url_t * ticket)
 }
 
 static int
-get_user (url_t url, const char *filename, char **user)
+get_user (mu_url_t url, const char *filename, char **user)
 {
   char *u = 0;
 
   if (url)
     {
       size_t n = 0;
-      url_get_user (url, NULL, 0, &n);
+      mu_url_get_user (url, NULL, 0, &n);
 
       if (n)
 	{
 	  u = calloc (1, n + 1);
-	  url_get_user (url, u, n + 1, NULL);
+	  mu_url_get_user (url, u, n + 1, NULL);
 	}
     }
   if (!u && filename)
     {
-      url_t ticket = 0;
+      mu_url_t ticket = 0;
       int e = get_ticket (url, NULL, filename, &ticket);
       if (e)
 	return e;
@@ -398,14 +400,14 @@ get_user (url_t url, const char *filename, char **user)
       if (ticket)
 	{
 	  size_t n = 0;
-	  url_get_user (ticket, NULL, 0, &n);
+	  mu_url_get_user (ticket, NULL, 0, &n);
 
 	  if (n)
 	    {
 	      u = calloc (1, n + 1);
-	      url_get_user (ticket, u, n + 1, NULL);
+	      mu_url_get_user (ticket, u, n + 1, NULL);
 	    }
-	  url_destroy (&ticket);
+	  mu_url_destroy (&ticket);
 	}
     }
   else
@@ -424,24 +426,24 @@ get_user (url_t url, const char *filename, char **user)
 }
 
 static int
-get_pass (url_t url, const char *user, const char *filename, char **pass)
+get_pass (mu_url_t url, const char *user, const char *filename, char **pass)
 {
   char *u = 0;
 
   if (url)
     {
       size_t n = 0;
-      url_get_passwd (url, NULL, 0, &n);
+      mu_url_get_passwd (url, NULL, 0, &n);
 
       if (n)
 	{
 	  u = calloc (1, n + 1);
-	  url_get_passwd (url, u, n + 1, NULL);
+	  mu_url_get_passwd (url, u, n + 1, NULL);
 	}
     }
   if (!u && filename)
     {
-      url_t ticket = 0;
+      mu_url_t ticket = 0;
       int e = get_ticket (url, user, filename, &ticket);
       if (e)
 	return e;
@@ -449,14 +451,14 @@ get_pass (url_t url, const char *user, const char *filename, char **pass)
       if (ticket)
 	{
 	  size_t n = 0;
-	  url_get_passwd (ticket, NULL, 0, &n);
+	  mu_url_get_passwd (ticket, NULL, 0, &n);
 
 	  if (n)
 	    {
 	      u = calloc (1, n + 1);
-	      url_get_passwd (ticket, u, n + 1, NULL);
+	      mu_url_get_passwd (ticket, u, n + 1, NULL);
 	    }
-	  url_destroy (&ticket);
+	  mu_url_destroy (&ticket);
 	}
     }
   *pass = u;
