@@ -22,10 +22,8 @@
 #include <mh.h>
 
 const char *program_version = "inc (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH inc\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH inc")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder]");
 
 /* GNU options */
