@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* Global MH state. */
 
@@ -30,7 +31,7 @@ int mh_auto_install = 1;
 /* Global profile */
 
 char *
-mh_global_profile_get (char *name, char *defval)
+mh_global_profile_get (char *name, const char *defval)
 {
   return mh_context_get_value (profile, name, defval);
 }
@@ -71,6 +72,9 @@ mh_read_profile ()
   mh_context_read (profile);
 
   mh_set_reply_regex (mh_global_profile_get ("Reply-Regex", NULL));
+  p = mh_global_profile_get ("Decode-Fallback", NULL);
+  if (p && mu_set_default_fallback (p))
+    mu_error (_("Incorrect value for decode-fallback"));
 }
 
 /* Global context */
@@ -82,7 +86,7 @@ _mh_init_global_context ()
   
   if (context)
     return;
-  mu_path_folder_dir = mh_get_dir ();
+  mu_set_folder_directory (mh_get_dir ());
   p = getenv ("CONTEXT");
   if (!p)
     p = MH_CONTEXT_FILE;
@@ -179,9 +183,7 @@ mh_global_sequences_iterate (mh_context_iterator fp, void *data)
 void
 mh_global_save_state ()
 {
-  char buf[64];
-  snprintf (buf, sizeof buf, "%lu", (unsigned long) current_message);
-  mh_context_set_value (sequences, "cur", buf);
+  mh_context_set_value (sequences, "cur", mu_umaxtostr (0, current_message));
   mh_context_write (sequences);
 
   mh_context_set_value (context, "Current-Folder", current_folder);
