@@ -23,10 +23,8 @@
 #include <unistd.h>
 
 const char *program_version = "mhl (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH mhl\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH mhl")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[files]");
 
 /* GNU options */
@@ -165,13 +163,13 @@ open_output ()
 
   if (rc)
     {
-      mh_error (_("Cannot create output stream: %s"), mu_strerror (rc));
+      mu_error (_("Cannot create output stream: %s"), mu_strerror (rc));
       exit (1);
     }
 
   if ((rc = mu_stream_open (output)))
     {
-      mh_error (_("Cannot open output stream: %s"), mu_strerror (rc));
+      mu_error (_("Cannot open output stream: %s"), mu_strerror (rc));
       exit (1);
     }
   return output;
@@ -190,13 +188,13 @@ list_message (char *name, mu_stream_t output)
     rc = mu_file_stream_create (&input, name, MU_STREAM_READ);
   if (rc)
     {
-      mh_error (_("Cannot create input stream: %s"), mu_strerror (rc));
+      mu_error (_("Cannot create input stream: %s"), mu_strerror (rc));
       return;
     }
 
   if ((rc = mu_stream_open (input)))
     {
-      mh_error (_("Cannot open input stream: %s"), mu_strerror (rc));
+      mu_error (_("Cannot open input stream: %s"), mu_strerror (rc));
       mu_stream_destroy (&input, mu_stream_get_owner (input));
       return;
     }
@@ -204,7 +202,7 @@ list_message (char *name, mu_stream_t output)
   msg = mh_stream_to_message (input);
   if (!msg)
     {
-      mh_error (_("Input stream %s is not a message (%s)"),
+      mu_error (_("Input stream %s is not a message (%s)"),
 		name, mu_strerror (rc));
       mu_stream_close (input);
       mu_stream_destroy (&input, mu_stream_get_owner (input));
