@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005  Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -57,6 +57,6 @@ struct node
   } v;
 };
 
-void pick_add_token __P((list_t *list, int tok, char *val));
-int pick_parse __P((list_t toklist));
-int pick_eval __P((message_t msg));
+void pick_add_token (mu_list_t *list, int tok, char *val);
+int pick_parse (mu_list_t toklist);
+int pick_eval (mu_message_t msg);
