@@ -24,10 +24,8 @@
 #include <unistd.h>
 
 const char *program_version = "reply (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH repl\v\
-Options marked with `*' are not yet implemented.\n\
+static char doc[] = N_("GNU MH repl")"\v"
+N_("Options marked with `*' are not yet implemented.\n\
 Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder] [msg]");
 
