@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002, 2005 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,10 +30,8 @@
 #include <dirent.h>
 
 const char *program_version = "rmf (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH rmf\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH rmf")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder]");
 
 /* GNU options */
@@ -125,7 +123,7 @@ rmf (const char *name)
 
   if (!dir)
     {
-      mh_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
+      mu_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
       return 1;
     }
 
@@ -144,7 +142,7 @@ rmf (const char *name)
       asprintf (&p, "%s/%s", name, entry->d_name);
       if (stat (p, &st) < 0)
 	{
-	  mh_error (_("Cannot stat %s: %s"), p, strerror (errno));
+	  mu_error (_("Cannot stat %s: %s"), p, strerror (errno));
 	}
       else if (S_ISDIR (st.st_mode))
 	{
@@ -161,7 +159,7 @@ rmf (const char *name)
 	{
 	  if (unlink (p))
 	    {
-	      mh_error (_("Cannot unlink %s: %s"), p, strerror (errno));
+	      mu_error (_("Cannot unlink %s: %s"), p, strerror (errno));
 	      failures++;
 	    }
 	}
@@ -199,12 +197,16 @@ main (int argc, char **argv)
   mu_argp_init (program_version, NULL);
   mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, NULL);
-  if (!explicit_folder)
-    interactive = 1;
 
   cur_folder_path = current_folder_path ();
 
-  name = mh_expand_name (NULL, folder_name, 0);
+  if (!explicit_folder)
+    {
+      interactive = 1;
+      name = cur_folder_path;
+    }
+  else
+    name = mh_expand_name (NULL, folder_name, 0);
   rmf (name);
   return 0;
 }
