@@ -21,10 +21,8 @@
 #include <mh.h>
 
 const char *program_version = "rmm (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH rmm\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH rmm")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder] [msgs]");
 
 /* GNU options */
