@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 
+   2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,10 +29,8 @@
 #include <mailutils/observer.h>
 
 const char *program_version = "scan (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH scan\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH scan")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder] [msgs]");
 
 /* GNU options */
@@ -84,9 +83,9 @@ static mh_format_t format;
 
 static mh_msgset_t msgset;
 
-void list_message __P((mailbox_t mbox, message_t msg, size_t num, void *data));
-void print_header __P((mailbox_t mbox));
-void clear_screen __P((void));
+void list_message (mu_mailbox_t mbox, mu_message_t msg, size_t num, void *data);
+void print_header (mu_mailbox_t mbox);
+void clear_screen (void);
 
 static int
 opt_handler (int key, char *arg, void *unused, struct argp_state *state)
@@ -150,18 +149,18 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
 
 /* Observable Action this is being call at every message discover.  */
 static int
-action (observer_t o, size_t type)
+action (mu_observer_t o, size_t type)
 {
   static int counter;
-  mailbox_t mbox;
-  message_t msg = NULL;
+  mu_mailbox_t mbox;
+  mu_message_t msg = NULL;
   size_t num;
 
   if (type == MU_EVT_MESSAGE_ADD)
     {
-      mbox = observer_get_owner (o);
+      mbox = mu_observer_get_owner (o);
       counter++;
-      mailbox_get_message (mbox, counter, &msg);
+      mu_mailbox_get_message (mbox, counter, &msg);
       mh_message_number (msg, &num);
       list_message (mbox, msg, num, NULL);
     }
@@ -172,7 +171,7 @@ int
 main (int argc, char **argv)
 {
   int index;
-  mailbox_t mbox;
+  mu_mailbox_t mbox;
   int status;
   size_t total = 0;
   
@@ -185,7 +184,7 @@ main (int argc, char **argv)
 
   if (mh_format_parse (format_str, &format))
     {
-      mh_error (_("Bad format string"));
+      mu_error (_("Bad format string"));
       exit (1);
     }
 
@@ -196,21 +195,21 @@ main (int argc, char **argv)
   if ((argc == 0 || strcmp (argv[0], "all") == 0) && !reverse)
     {
       /* Fast approach */
-      observer_t observer;
-      observable_t observable;
+      mu_observer_t observer;
+      mu_observable_t observable;
         
       print_header (mbox);
       
-      observer_create (&observer, mbox);
-      observer_set_action (observer, action, mbox);
-      mailbox_get_observable (mbox, &observable);
-      observable_attach (observable, MU_EVT_MESSAGE_ADD, observer);
+      mu_observer_create (&observer, mbox);
+      mu_observer_set_action (observer, action, mbox);
+      mu_mailbox_get_observable (mbox, &observable);
+      mu_observable_attach (observable, MU_EVT_MESSAGE_ADD, observer);
 
-      status = mailbox_scan (mbox, 1, &total);
+      status = mu_mailbox_scan (mbox, 1, &total);
     }
   else
     {
-      mailbox_messages_count (mbox, &total);
+      mu_mailbox_messages_count (mbox, &total);
       mh_msgset_parse (mbox, &msgset, argc, argv, "all");
 
       if (reverse)
@@ -222,10 +221,10 @@ main (int argc, char **argv)
 
   if (total == 0)
     {
-      url_t url = NULL;
+      mu_url_t url = NULL;
 
-      mailbox_get_url (mbox, &url);
-      mh_error (_("no messages in %s"), url_to_string (url));
+      mu_mailbox_get_url (mbox, &url);
+      mu_error (_("no messages in %s"), mu_url_to_string (url));
     }
 
   clear_screen ();
@@ -235,18 +234,18 @@ main (int argc, char **argv)
 }
 
 void
-print_header (mailbox_t mbox)
+print_header (mu_mailbox_t mbox)
 {
   if (header)
     {
-      url_t url = NULL;
+      mu_url_t url = NULL;
       char datestr[64];
       time_t t;
 	  
-      mailbox_get_url (mbox, &url);
+      mu_mailbox_get_url (mbox, &url);
       time (&t);
       strftime (datestr, sizeof datestr, "%c", localtime (&t));
-      printf (_("Folder %s  %s\n"), url_to_string (url), datestr);
+      printf (_("Folder %s  %s\n"), mu_url_to_string (url), datestr);
     }
 }
 
@@ -292,7 +291,7 @@ clear_screen ()
 }
 
 void
-list_message (mailbox_t mbox, message_t msg, size_t num, void *data)
+list_message (mu_mailbox_t mbox, mu_message_t msg, size_t num, void *data)
 {
   char *buffer;
   int len;
