@@ -25,10 +25,8 @@
 #include <pwd.h>
 
 const char *program_version = "send (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH send\v\
-Options marked with `*' are not yet implemented.\n\
+static char doc[] = N_("GNU MH send")"\v"
+N_("Options marked with `*' are not yet implemented.\n\
 Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("file [file...]");
 
