@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2005 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 #include <signal.h>
 
 const char *program_version = "sortm (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH sortm\v"
-"Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH sortm")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[msgs]");
 
 #define ARG_QUICKSORT 1024
@@ -45,8 +45,8 @@ static struct argp_option options[] = {
    N_("Consider two datefields equal if their difference lies within the given nuber of DAYS."), 11},
   {"nolimit",       ARG_NOLIMIT,       NULL,       0,
    N_("Undo the effect of the last --limit option"), 11},
-  {"textfield",     ARG_TEXTFIELD,     N_("STRING"), 15,
-   N_("Sort on the text field"), 1},
+  {"textfield",     ARG_TEXTFIELD,     N_("STRING"), 0,
+   N_("Sort on the text field"), 15},
   {"notextfield",   ARG_NOTEXTFIELD,   NULL,       0,
    N_("Undo the effect of the last --textfield option"), 15},
   {"numfield",      ARG_NUMFIELD,      N_("STRING"), 0,
@@ -216,7 +216,7 @@ addop (char *field, compfun comp)
   
   if (!oplist && mu_list_create (&oplist))
     {
-      mh_error (_("can't create operation list"));
+      mu_error (_("can't create operation list"));
       exit (1);
     }
   op->field = field;
@@ -554,7 +554,7 @@ main (int argc, char **argv)
 
   if (action == ACTION_LIST && mh_format_parse (format_str, &format))
     {
-      mh_error (_("Bad format string"));
+      mu_error (_("Bad format string"));
       exit (1);
     }
   
