@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "pop3d.h"
 
@@ -32,7 +33,7 @@ pop3d_capa (const char *arg)
   if (strlen (arg) != 0)
     return ERR_BAD_ARGS;
 
-  if (state != AUTHORIZATION && state != TRANSACTION)
+  if (state != initial_state && state != TRANSACTION)
     return ERR_WRONG_STATE;
 
   pop3d_outf ("+OK Capability list follows\r\n");
@@ -48,12 +49,15 @@ pop3d_capa (const char *arg)
 #endif /* WITH_TLS */
 
   login_delay_capa ();
-  /* This can be Implemented by setting an header field on the message.  */
+  /* This can be implemented by setting an header field on the message.  */
   if (expire < 0)
     pop3d_outf ("EXPIRE NEVER\r\n");
   else 
-    pop3d_outf ("EXPIRE %d\r\n", expire);
+    pop3d_outf ("EXPIRE %s\r\n", mu_umaxtostr (0, expire));
 
+  if (state == INITIAL)
+    pop3d_outf ("XTLSREQUIRED\r\n");
+  
   if (state == TRANSACTION)	/* let's not advertise to just anyone */
     pop3d_outf ("IMPLEMENTATION %s\r\n", PACKAGE_STRING);
   pop3d_outf (".\r\n");
