@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 
+   2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 
 #include "pop3d.h"
 
-mailbox_t mbox;
+mu_mailbox_t mbox;
 int state;
 char *username;
 char *md5shared;
@@ -54,12 +55,11 @@ char *login_stat_file = LOGIN_STAT_FILE;
 time_t expire = EXPIRE_NEVER; /* Expire messages after this number of days */
 int expire_on_exit = 0;       /* Delete expired messages on exit */
 
-static int pop3d_mainloop       __P ((int fd, FILE *, FILE *));
-static void pop3d_daemon_init   __P ((void));
-static void pop3d_daemon        __P ((unsigned int, unsigned int));
-static error_t pop3d_parse_opt  __P((int key, char *arg,
-				     struct argp_state *astate));
-static void pop3d_log_connection __P((int fd));
+static int pop3d_mainloop       (int fd, FILE *, FILE *);
+static void pop3d_daemon_init   (void);
+static void pop3d_daemon        (unsigned int, unsigned int);
+static error_t pop3d_parse_opt  (int key, char *arg, struct argp_state *astate);
+static void pop3d_log_connection (int fd);
 
 const char *program_version = "pop3d (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU pop3d -- the POP3 daemon");
@@ -243,7 +243,7 @@ main (int argc, char **argv)
 
   if (daemon_param.pidfile)
     {
-      daemon_create_pidfile (daemon_param.pidfile);
+      mu_daemon_create_pidfile (daemon_param.pidfile);
     }
 
   /* Check TLS environment, i.e. cert and key files */
@@ -384,11 +384,11 @@ pop3d_mainloop (int fd, FILE *infile, FILE *outfile)
 	 the lock may be stale because downloading on slow modem.
 	 We rely on the size of the mailbox for the check and bail if out
 	 of sync.  */
-      if (state == TRANSACTION && !mailbox_is_updated (mbox))
+      if (state == TRANSACTION && !mu_mailbox_is_updated (mbox))
 	{
-	  static off_t mailbox_size;
-	  off_t newsize = 0;
-	  mailbox_get_size (mbox, &newsize);
+	  static mu_off_t mailbox_size;
+	  mu_off_t newsize = 0;
+	  mu_mailbox_get_size (mbox, &newsize);
 	  /* Did we shrink?  First time save the size.  */
 	  if (!mailbox_size)
 	    mailbox_size = newsize;
@@ -528,8 +528,8 @@ pop3d_daemon (unsigned int maxchildren, unsigned int port)
       process_cleanup ();
       if (children > maxchildren)
         {
-	  syslog (LOG_ERR, _("too many children (%lu)"),
-		  (unsigned long) children);
+	  syslog (LOG_ERR, _("too many children (%s)"),
+		  mu_umaxtostr (0, children));
           pause ();
           continue;
         }
