@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 
+   2004, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -24,15 +25,14 @@
 
 #define WEEDLIST_SEPARATOR " :,"
 
-static void print_header __P ((message_t, int no_header,
-			       int all_header, const char *weedlst));
-static void print_body __P ((message_t));
-static int  string_starts_with __P ((const char * s1, const char *s2));
+static void print_header (mu_message_t, int no_header,
+			  int all_header, const char *weedlst);
+static void print_body (mu_message_t);
+static int  string_starts_with (const char * s1, const char *s2);
 
 const char *program_version = "readmsg (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU readmsg -- print messages");
-static error_t readmsg_parse_opt  __P((int key, char *arg,
-				       struct argp_state *astate));
+static error_t readmsg_parse_opt  (int key, char *arg, struct argp_state *astate);
 
 static struct argp_option options[] = 
 {
@@ -88,11 +88,11 @@ readmsg_parse_opt (int key, char *arg, struct argp_state *astate)
       break;
 
     case 'f':
-      mailbox_name = optarg;
+      mailbox_name = arg;
       break;
 
     case 'w':
-      weedlist = optarg;
+      weedlist = arg;
       break;
 
     case 'n':
@@ -133,25 +133,25 @@ string_starts_with (const char * s1, const char *s2)
 }
 
 static void
-print_header (message_t message, int no_header, int all_headers,
+print_header (mu_message_t message, int no_header, int all_headers,
 	      const char *weedlist)
 {
-  header_t header = NULL;
+  mu_header_t header = NULL;
 
   if (no_header)
     return;
 
-  message_get_header (message, &header);
+  mu_message_get_header (message, &header);
 
   if (all_headers)
     {
-      stream_t stream = NULL;
+      mu_stream_t stream = NULL;
       off_t offset = 0;
       size_t len = 0;
       char buf[128];
 
-      header_get_stream (header, &stream);
-      while (stream_read (stream, buf, sizeof (buf) - 1, offset, &len) == 0
+      mu_header_get_stream (header, &stream);
+      while (mu_stream_read (stream, buf, sizeof (buf) - 1, offset, &len) == 0
 	     && len != 0)
 	{
 	  buf[len] ='\0';
@@ -165,7 +165,7 @@ print_header (message_t message, int no_header, int all_headers,
       const char *delim = WEEDLIST_SEPARATOR;
       size_t i;
 
-      header_get_field_count (header, &count);
+      mu_header_get_field_count (header, &count);
 
       for (i = 1; i <= count; i++)
 	{
@@ -174,14 +174,14 @@ print_header (message_t message, int no_header, int all_headers,
 	  char *weedcopy = strdup (weedlist);
 	  char *token, *s;
 
-	  header_aget_field_name (header, i, &name);
-	  header_aget_field_value (header, i, &value);
+	  mu_header_aget_field_name (header, i, &name);
+	  mu_header_aget_field_value (header, i, &value);
 	  for (token = strtok_r (weedcopy, delim, &s); token;
 	       token = strtok_r (NULL, delim, &s)) 
 	    {
 	      if (string_starts_with (name, token))
 		{
-		  /* Check if header_aget_value return an empty string.  */
+		  /* Check if mu_header_aget_value return an empty string.  */
 		  if (value && *value)
 		    printf ("%s: %s\n", name, value);
 		}
@@ -195,17 +195,17 @@ print_header (message_t message, int no_header, int all_headers,
 }
 
 static void
-print_body (message_t message)
+print_body (mu_message_t message)
 {
   char buf[128];
-  body_t body = NULL;
-  stream_t stream = NULL;
+  mu_body_t body = NULL;
+  mu_stream_t stream = NULL;
   off_t offset = 0;
   size_t len = 0;
-  message_get_body (message, &body);
-  body_get_stream (body, &stream);
+  mu_message_get_body (message, &body);
+  mu_body_get_stream (body, &stream);
 
-  while (stream_read (stream, buf, sizeof (buf) - 1, offset, &len) == 0
+  while (mu_stream_read (stream, buf, sizeof (buf) - 1, offset, &len) == 0
 	 && len != 0)
     {
       buf[len] ='\0';
@@ -227,7 +227,7 @@ main (int argc, char **argv)
   int n = 0;
   int i;
   int index;
-  mailbox_t mbox = NULL;
+  mu_mailbox_t mbox = NULL;
 
   /* Native Language Support */
   mu_init_nls ();
@@ -242,12 +242,16 @@ main (int argc, char **argv)
   mu_register_all_mbox_formats ();
   mu_register_extra_formats ();
 
-  status = mailbox_create_default (&mbox, mailbox_name);
+  status = mu_mailbox_create_default (&mbox, mailbox_name);
   if (status != 0)
     {
-      fprintf (stderr, _("Couldn't create mailbox <%s>: %s.\n"),
-	       mailbox_name ? mailbox_name : _("default"),
-	       mu_strerror(status));
+      if (mailbox_name)
+	fprintf (stderr, _("Could not create mailbox `%s': %s\n"),
+		 mailbox_name,
+		 mu_strerror(status));
+      else
+	fprintf (stderr, _("Could not create default mailbox: %s\n"),
+		 mu_strerror(status));
       exit (2);
     }
 
@@ -255,18 +259,18 @@ main (int argc, char **argv)
   if (dbug)
     {
       mu_debug_t debug;
-      mailbox_get_debug (mbox, &debug);
+      mu_mailbox_get_debug (mbox, &debug);
       mu_debug_set_level (debug, MU_DEBUG_TRACE|MU_DEBUG_PROT);
     }
 
-  status = mailbox_open (mbox, MU_STREAM_READ);
+  status = mu_mailbox_open (mbox, MU_STREAM_READ);
   if (status != 0)
     {
-      url_t url = NULL;
+      mu_url_t url = NULL;
 
-      mailbox_get_url (mbox, &url);
-      fprintf (stderr, _("Couldn't open mailbox <%s>: %s.\n"),
-	       url_to_string (url), mu_strerror(status));
+      mu_mailbox_get_url (mbox, &url);
+      fprintf (stderr, _("Could not open mailbox `%s': %s\n"),
+	       mu_url_to_string (url), mu_strerror(status));
       exit (2);
     }
 
@@ -280,12 +284,12 @@ main (int argc, char **argv)
 
   for (i = 0; i < n; ++i)
     {
-      message_t msg = NULL;
+      mu_message_t msg = NULL;
 
-      status = mailbox_get_message (mbox, set[i], &msg);
+      status = mu_mailbox_get_message (mbox, set[i], &msg);
       if (status != 0)
 	{
-	  mu_error ("mailbox_get_message: %s",
+	  mu_error ("mu_mailbox_get_message: %s",
 		    mu_strerror (status));
 	  exit (2);
 	}
@@ -300,7 +304,7 @@ main (int argc, char **argv)
 
   putchar ('\n');
 
-  mailbox_close (mbox);
-  mailbox_destroy (&mbox);
+  mu_mailbox_close (mbox);
+  mu_mailbox_destroy (&mbox);
   return 0;
 }
