@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005  Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,6 +19,9 @@
 #ifndef _READMSG_H
 #define _READMSG_H
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,7 +48,7 @@
 #include <mailutils/argp.h>
 #include <mailutils/error.h>
 
-int msglist __P ((mailbox_t mbox, int show_all, int argc, char **argv, int **set, int *n));
+int msglist (mu_mailbox_t mbox, int show_all, int argc, char **argv, int **set, int *n);
 
 #endif
 
